"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations.concurrent import LazyInit
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import Arrays
from java.util import Collections
from java.util import Comparator
from java.util import Iterator
from java.util import NavigableSet
from java.util import SortedSet
from java.util import Spliterator
from java.util.function import Consumer
from java.util.stream import Collector
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedSet(CachingAsList, NavigableSet, SortedIterable):

    @staticmethod
    def toImmutableSortedSet(comparator: "Comparator"["E"]) -> "Collector"["E", Any, "ImmutableSortedSet"["E"]]:
        """
        Returns a `Collector` that accumulates the input elements into a new `ImmutableSortedSet`, ordered by the specified comparator.
        
        If the elements contain duplicates (according to the comparator), only the first duplicate
        in encounter order will appear in the result.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableSortedSet"["E"]:
        """
        Returns the empty immutable sorted set.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(e1: "E") -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing a single element.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to Comparable.compareTo, only the first
        one specified is included.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to Comparable.compareTo, only the first
        one specified is included.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to Comparable.compareTo, only the first
        one specified is included.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to Comparable.compareTo, only the first
        one specified is included.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *remaining: Tuple["E", ...]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to Comparable.compareTo, only the first
        one specified is included.

        Raises
        - NullPointerException: if any element is null

        Since
        - 3.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def copyOf(elements: list["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to Comparable.compareTo, only the first
        one specified is included.

        Raises
        - NullPointerException: if any of `elements` is null

        Since
        - 3.0
        """
        ...


    @staticmethod
    def copyOf(elements: Iterable["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to `compareTo()`, only the first one
        specified is included. To create a copy of a `SortedSet` that preserves the comparator,
        call .copyOfSorted instead. This method iterates over `elements` at most once.
        
        Note that if `s` is a `Set<String>`, then `ImmutableSortedSet.copyOf(s)`
        returns an `ImmutableSortedSet<String>` containing each of the strings in `s`,
        while `ImmutableSortedSet.of(s)` returns an `ImmutableSortedSet<Set<String>>`
        containing one element (the given set itself).
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.
        
        This method is not type-safe, as it may be called on elements that are not mutually
        comparable.

        Raises
        - ClassCastException: if the elements are not mutually comparable
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(elements: Iterable["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to `compareTo()`, only the first one
        specified is included. To create a copy of a `SortedSet` that preserves the comparator,
        call .copyOfSorted instead. This method iterates over `elements` at most once.
        
        Note that if `s` is a `Set<String>`, then `ImmutableSortedSet.copyOf(s)`
        returns an `ImmutableSortedSet<String>` containing each of the strings in `s`,
        while `ImmutableSortedSet.of(s)` returns an `ImmutableSortedSet<Set<String>>`
        containing one element (the given set itself).
        
        **Note:** Despite what the method name suggests, if `elements` is an `ImmutableSortedSet`, it may be returned instead of a copy.
        
        This method is not type-safe, as it may be called on elements that are not mutually
        comparable.
        
        This method is safe to use even when `elements` is a synchronized or concurrent
        collection that is currently being modified by another thread.

        Raises
        - ClassCastException: if the elements are not mutually comparable
        - NullPointerException: if any of `elements` is null

        Since
        - 7.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def copyOf(elements: Iterator["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by their natural ordering.
        When multiple elements are equivalent according to `compareTo()`, only the first one
        specified is included.
        
        This method is not type-safe, as it may be called on elements that are not mutually
        comparable.

        Raises
        - ClassCastException: if the elements are not mutually comparable
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(comparator: "Comparator"["E"], elements: Iterator["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by the given `Comparator`. When multiple elements are equivalent according to `compareTo()`, only the
        first one specified is included.

        Raises
        - NullPointerException: if `comparator` or any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(comparator: "Comparator"["E"], elements: Iterable["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by the given `Comparator`. When multiple elements are equivalent according to `compare()`, only the
        first one specified is included. This method iterates over `elements` at most once.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if `comparator` or any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(comparator: "Comparator"["E"], elements: Iterable["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the given elements sorted by the given `Comparator`. When multiple elements are equivalent according to `compareTo()`, only the
        first one specified is included.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.
        
        This method is safe to use even when `elements` is a synchronized or concurrent
        collection that is currently being modified by another thread.

        Raises
        - NullPointerException: if `comparator` or any of `elements` is null

        Since
        - 7.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def copyOfSorted(sortedSet: "SortedSet"["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an immutable sorted set containing the elements of a sorted set, sorted by the same
        `Comparator`. That behavior differs from .copyOf(Iterable), which always uses the
        natural ordering of the elements.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.
        
        This method is safe to use even when `sortedSet` is a synchronized or concurrent
        collection that is currently being modified by another thread.

        Raises
        - NullPointerException: if `sortedSet` or any of its elements is null
        """
        ...


    @staticmethod
    def orderedBy(comparator: "Comparator"["E"]) -> "Builder"["E"]:
        """
        Returns a builder that creates immutable sorted sets with an explicit comparator. If the
        comparator has a more general type than the set being generated, such as creating a `SortedSet<Integer>` with a `Comparator<Number>`, use the Builder constructor
        instead.

        Raises
        - NullPointerException: if `comparator` is null
        """
        ...


    @staticmethod
    def reverseOrder() -> "Builder"["E"]:
        """
        Returns a builder that creates immutable sorted sets whose elements are ordered by the reverse
        of their natural ordering.
        """
        ...


    @staticmethod
    def naturalOrder() -> "Builder"["E"]:
        """
        Returns a builder that creates immutable sorted sets whose elements are ordered by their
        natural ordering. The sorted sets use Ordering.natural() as the comparator. This method
        provides more type-safety than .builder, as it can be called only for classes that
        implement Comparable.
        """
        ...


    def comparator(self) -> "Comparator"["E"]:
        """
        Returns the comparator that orders the elements, which is Ordering.natural() when the
        natural ordering of the elements is used. Note that its behavior is not consistent with SortedSet.comparator(), which returns `null` to indicate natural ordering.
        """
        ...


    def iterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    def headSet(self, toElement: "E") -> "ImmutableSortedSet"["E"]:
        """
        
        
        This method returns a serializable `ImmutableSortedSet`.
        
        The SortedSet.headSet documentation states that a subset of a subset throws an
        IllegalArgumentException if passed a `toElement` greater than an earlier `toElement`. However, this method doesn't throw an exception in that situation, but instead
        keeps the original `toElement`.
        """
        ...


    def headSet(self, toElement: "E", inclusive: bool) -> "ImmutableSortedSet"["E"]:
        """
        Since
        - 12.0
        """
        ...


    def subSet(self, fromElement: "E", toElement: "E") -> "ImmutableSortedSet"["E"]:
        """
        
        
        This method returns a serializable `ImmutableSortedSet`.
        
        The SortedSet.subSet documentation states that a subset of a subset throws an IllegalArgumentException if passed a `fromElement` smaller than an earlier `fromElement`. However, this method doesn't throw an exception in that situation, but instead
        keeps the original `fromElement`. Similarly, this method keeps the original `toElement`, instead of throwing an exception, if passed a `toElement` greater than an
        earlier `toElement`.
        """
        ...


    def subSet(self, fromElement: "E", fromInclusive: bool, toElement: "E", toInclusive: bool) -> "ImmutableSortedSet"["E"]:
        """
        Since
        - 12.0
        """
        ...


    def tailSet(self, fromElement: "E") -> "ImmutableSortedSet"["E"]:
        """
        
        
        This method returns a serializable `ImmutableSortedSet`.
        
        The SortedSet.tailSet documentation states that a subset of a subset throws an
        IllegalArgumentException if passed a `fromElement` smaller than an earlier `fromElement`. However, this method doesn't throw an exception in that situation, but instead
        keeps the original `fromElement`.
        """
        ...


    def tailSet(self, fromElement: "E", inclusive: bool) -> "ImmutableSortedSet"["E"]:
        """
        Since
        - 12.0
        """
        ...


    def lower(self, e: "E") -> "E":
        """
        Since
        - 12.0
        """
        ...


    def floor(self, e: "E") -> "E":
        """
        Since
        - 12.0
        """
        ...


    def ceiling(self, e: "E") -> "E":
        """
        Since
        - 12.0
        """
        ...


    def higher(self, e: "E") -> "E":
        """
        Since
        - 12.0
        """
        ...


    def first(self) -> "E":
        ...


    def last(self) -> "E":
        ...


    def pollFirst(self) -> "E":
        """
        Guaranteed to throw an exception and leave the set unmodified.

        Raises
        - UnsupportedOperationException: always

        Since
        - 12.0

        Deprecated
        - Unsupported operation.
        """
        ...


    def pollLast(self) -> "E":
        """
        Guaranteed to throw an exception and leave the set unmodified.

        Raises
        - UnsupportedOperationException: always

        Since
        - 12.0

        Deprecated
        - Unsupported operation.
        """
        ...


    def descendingSet(self) -> "ImmutableSortedSet"["E"]:
        """
        Since
        - 12.0
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        ...


    def descendingIterator(self) -> "UnmodifiableIterator"["E"]:
        """
        Since
        - 12.0
        """
        ...


    @staticmethod
    def toImmutableSet() -> "Collector"["E", Any, "ImmutableSet"["E"]]:
        """
        Not supported. Use .toImmutableSortedSet instead. This method exists only to hide
        ImmutableSet.toImmutableSet from consumers of `ImmutableSortedSet`.

        Raises
        - UnsupportedOperationException: always

        Since
        - 21.0

        Deprecated
        - Use ImmutableSortedSet.toImmutableSortedSet.
        """
        ...


    @staticmethod
    def builder() -> "ImmutableSortedSet.Builder"["E"]:
        """
        Not supported. Use .naturalOrder, which offers better type-safety, instead. This method
        exists only to hide ImmutableSet.builder from consumers of `ImmutableSortedSet`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedSet.naturalOrder, which offers better type-safety.
        """
        ...


    @staticmethod
    def builderWithExpectedSize(expectedSize: int) -> "ImmutableSortedSet.Builder"["E"]:
        """
        Not supported. This method exists only to hide ImmutableSet.builderWithExpectedSize
        from consumers of `ImmutableSortedSet`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Not supported by ImmutableSortedSet.
        """
        ...


    @staticmethod
    def of(e1: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass a parameter of type `Comparable` to use ImmutableSortedSet.of(Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable, Comparable, Comparable). **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of( Comparable, Comparable, Comparable, Comparable, Comparable). **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *remaining: Tuple["E", ...]) -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable, Comparable, Comparable, Comparable,
            Comparable, Comparable...). **
        """
        ...


    @staticmethod
    def copyOf(elements: list["Z"]) -> "ImmutableSortedSet"["Z"]:
        """
        Not supported. **You are attempting to create a set that may contain non-`Comparable`
        elements.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass parameters of type `Comparable` to use ImmutableSortedSet.copyOf(Comparable[]).**
        """
        ...


    class Builder(Builder):
        """
        A builder for creating immutable sorted set instances, especially `public static final`
        sets ("constant sets"), with a given comparator. Example:
        
        ````public static final ImmutableSortedSet<Number> LUCKY_NUMBERS =
            new ImmutableSortedSet.Builder<Number>(ODDS_FIRST_COMPARATOR)
                .addAll(SINGLE_DIGIT_PRIMES)
                .add(42)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple sets in series. Each set is a superset of the set created before it.

        Since
        - 2.0
        """

        def __init__(self, comparator: "Comparator"["E"]):
            ...


        def add(self, element: "E") -> "Builder"["E"]:
            """
            Adds `element` to the `ImmutableSortedSet`. If the `ImmutableSortedSet`
            already contains `element`, then `add` has no effect. (only the previously added
            element is retained).

            Arguments
            - element: the element to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            """
            ...


        def add(self, *elements: Tuple["E", ...]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSortedSet`, ignoring duplicate
            elements (only the first duplicate element is added).

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` contains a null element
            """
            ...


        def addAll(self, elements: Iterable["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSortedSet`, ignoring duplicate
            elements (only the first duplicate element is added).

            Arguments
            - elements: the elements to add to the `ImmutableSortedSet`

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` contains a null element
            """
            ...


        def addAll(self, elements: Iterator["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSortedSet`, ignoring duplicate
            elements (only the first duplicate element is added).

            Arguments
            - elements: the elements to add to the `ImmutableSortedSet`

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` contains a null element
            """
            ...


        def build(self) -> "ImmutableSortedSet"["E"]:
            """
            Returns a newly-created `ImmutableSortedSet` based on the contents of the `Builder` and its comparator.
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.block.Action

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class Action(Enum):

    LEFT_CLICK_BLOCK = 0
    """
    Left-clicking a block
    """
    RIGHT_CLICK_BLOCK = 1
    """
    Right-clicking a block
    """
    LEFT_CLICK_AIR = 2
    """
    Left-clicking the air
    """
    RIGHT_CLICK_AIR = 3
    """
    Right-clicking the air
    """
    PHYSICAL = 4
    """
    Stepping onto or into a block (Ass-pressure)
    
    Examples:
    
    - Jumping on soil
    - Standing on pressure plate
    - Triggering redstone ore
    - Triggering tripwire
    """



"""
Python module generated from Java source file org.bukkit.conversations.ConversationPrefix

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.conversations import *
from typing import Any, Callable, Iterable, Tuple


class ConversationPrefix:
    """
    A ConversationPrefix implementation prepends all output from the
    conversation to the player. The ConversationPrefix can be used to display
    the plugin name or conversation status as the conversation evolves.
    """

    def getPrefix(self, context: "ConversationContext") -> str:
        """
        Gets the prefix to use before each message to the player.

        Arguments
        - context: Context information about the conversation.

        Returns
        - The prefix text.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.PinkPetals

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class PinkPetals(Directional):
    """
    'flower_amount' represents the number of petals.
    """

    def getFlowerAmount(self) -> int:
        """
        Gets the value of the 'flower_amount' property.

        Returns
        - the 'flower_amount' value
        """
        ...


    def setFlowerAmount(self, flower_amount: int) -> None:
        """
        Sets the value of the 'flower_amount' property.

        Arguments
        - flower_amount: the new 'flower_amount' value
        """
        ...


    def getMaximumFlowerAmount(self) -> int:
        """
        Gets the maximum allowed value of the 'flower_amount' property.

        Returns
        - the maximum 'flower_amount' value
        """
        ...



"""
Python module generated from Java source file com.google.common.cache.LocalCache

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Equivalence
from com.google.common.base import Stopwatch
from com.google.common.base import Ticker
from com.google.common.cache import *
from com.google.common.cache.AbstractCache import SimpleStatsCounter
from com.google.common.cache.AbstractCache import StatsCounter
from com.google.common.cache.CacheBuilder import NullListener
from com.google.common.cache.CacheBuilder import OneWeigher
from com.google.common.cache.CacheLoader import InvalidCacheLoadException
from com.google.common.cache.CacheLoader import UnsupportedLoadingOperationException
from com.google.common.collect import AbstractSequentialIterator
from com.google.common.collect import ImmutableMap
from com.google.common.collect import ImmutableSet
from com.google.common.collect import Maps
from com.google.common.collect import Sets
from com.google.common.primitives import Ints
from com.google.common.util.concurrent import ExecutionError
from com.google.common.util.concurrent import Futures
from com.google.common.util.concurrent import ListenableFuture
from com.google.common.util.concurrent import SettableFuture
from com.google.common.util.concurrent import UncheckedExecutionException
from com.google.common.util.concurrent import Uninterruptibles
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import GuardedBy
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from com.google.j2objc.annotations import Weak
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import SoftReference
from java.lang.ref import WeakReference
from java.util import AbstractCollection
from java.util import AbstractQueue
from java.util import AbstractSet
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Queue
from java.util.concurrent import Callable
from java.util.concurrent import ConcurrentLinkedQueue
from java.util.concurrent import ConcurrentMap
from java.util.concurrent import ExecutionException
from java.util.concurrent import TimeUnit
from java.util.concurrent.atomic import AtomicInteger
from java.util.concurrent.atomic import AtomicReferenceArray
from java.util.concurrent.locks import ReentrantLock
from java.util.function import BiFunction
from java.util.function import BiPredicate
from java.util.function import Function
from java.util.function import Predicate
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class LocalCache(AbstractMap, ConcurrentMap):
    """
    The concurrent hash map implementation built by CacheBuilder.
    
    This implementation is heavily derived from revision 1.96 of <a
    href="http://tinyurl.com/ConcurrentHashMap">ConcurrentHashMap.java</a>.

    Author(s)
    - Doug Lea (`ConcurrentHashMap`)
    """

    def cleanUp(self) -> None:
        ...


    def isEmpty(self) -> bool:
        ...


    def size(self) -> int:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def getIfPresent(self, key: "Object") -> "V":
        ...


    def getOrDefault(self, key: "Object", defaultValue: "V") -> "V":
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def putIfAbsent(self, key: "K", value: "V") -> "V":
        ...


    def compute(self, key: "K", function: "BiFunction"["K", "V", "V"]) -> "V":
        ...


    def computeIfAbsent(self, key: "K", function: "Function"["K", "V"]) -> "V":
        ...


    def computeIfPresent(self, key: "K", function: "BiFunction"["K", "V", "V"]) -> "V":
        ...


    def merge(self, key: "K", newValue: "V", function: "BiFunction"["V", "V", "V"]) -> "V":
        ...


    def putAll(self, m: dict["K", "V"]) -> None:
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        ...


    def replace(self, key: "K", oldValue: "V", newValue: "V") -> bool:
        ...


    def replace(self, key: "K", value: "V") -> "V":
        ...


    def clear(self) -> None:
        ...


    def keySet(self) -> set["K"]:
        ...


    def values(self) -> Iterable["V"]:
        ...


    def entrySet(self) -> set["Entry"["K", "V"]]:
        ...



"""
Python module generated from Java source file org.bukkit.util.ChatPaginator

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from org.bukkit import ChatColor
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class ChatPaginator:
    """
    The ChatPaginator takes a raw string of arbitrary length and breaks it down
    into an array of strings appropriate for displaying on the Minecraft player
    console.
    """

    GUARANTEED_NO_WRAP_CHAT_PAGE_WIDTH = 55
    AVERAGE_CHAT_PAGE_WIDTH = 65
    UNBOUNDED_PAGE_WIDTH = Integer.MAX_VALUE
    OPEN_CHAT_PAGE_HEIGHT = 20
    CLOSED_CHAT_PAGE_HEIGHT = 10
    UNBOUNDED_PAGE_HEIGHT = Integer.MAX_VALUE


    @staticmethod
    def paginate(unpaginatedString: str, pageNumber: int) -> "ChatPage":
        """
        Breaks a raw string up into pages using the default width and height.

        Arguments
        - unpaginatedString: The raw string to break.
        - pageNumber: The page number to fetch.

        Returns
        - A single chat page.
        """
        ...


    @staticmethod
    def paginate(unpaginatedString: str, pageNumber: int, lineLength: int, pageHeight: int) -> "ChatPage":
        """
        Breaks a raw string up into pages using a provided width and height.

        Arguments
        - unpaginatedString: The raw string to break.
        - pageNumber: The page number to fetch.
        - lineLength: The desired width of a chat line.
        - pageHeight: The desired number of lines in a page.

        Returns
        - A single chat page.
        """
        ...


    @staticmethod
    def wordWrap(rawString: str, lineLength: int) -> list[str]:
        """
        Breaks a raw string up into a series of lines. Words are wrapped using
        spaces as decimeters and the newline character is respected.

        Arguments
        - rawString: The raw string to break.
        - lineLength: The length of a line of text.

        Returns
        - An array of word-wrapped lines.
        """
        ...


    class ChatPage:

        def __init__(self, lines: list[str], pageNumber: int, totalPages: int):
            ...


        def getPageNumber(self) -> int:
            ...


        def getTotalPages(self) -> int:
            ...


        def getLines(self) -> list[str]:
            ...



"""
Python module generated from Java source file org.bukkit.inventory.BlockInventoryHolder

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class BlockInventoryHolder(InventoryHolder):
    """
    Represents a block inventory holder - either a BlockState, or a regular
    Block.
    """

    def getBlock(self) -> "Block":
        """
        Gets the block associated with this holder.

        Returns
        - the block associated with this holder

        Raises
        - IllegalStateException: if the holder is a block state and is not
        placed
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.InventoryBlockStartEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from org.bukkit.event.inventory import FurnaceStartSmeltEvent
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class InventoryBlockStartEvent(BlockEvent):
    """
    Used when:
    
    - A Furnace starts smelting FurnaceStartSmeltEvent
    - A Brewing-Stand starts brewing BrewingStartEvent
    - A Campfire starts cooking CampfireStartEvent
    """

    def __init__(self, block: "Block", source: "ItemStack"):
        ...


    def getSource(self) -> "ItemStack":
        """
        Gets the source ItemStack for this event.

        Returns
        - the source ItemStack
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.text.NumberFormat

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.math import BigInteger
from java.math import RoundingMode
from java.text import *
from java.text.spi import NumberFormatProvider
from java.util import Currency
from java.util import Locale
from java.util import Objects
from java.util.concurrent.atomic import AtomicInteger
from java.util.concurrent.atomic import AtomicLong
from sun.util.locale.provider import LocaleProviderAdapter
from sun.util.locale.provider import LocaleServiceProviderPool
from typing import Any, Callable, Iterable, Tuple


class NumberFormat(Format):
    """
    `NumberFormat` is the abstract base class for all number
    formats. This class provides the interface for formatting and parsing
    numbers. `NumberFormat` also provides methods for determining
    which locales have number formats, and what their names are.
    
    
    `NumberFormat` helps you to format and parse numbers for any locale.
    Your code can be completely independent of the locale conventions for
    decimal points, thousands-separators, or even the particular decimal
    digits used, or whether the number format is even decimal.
    
    
    To format a number for the current Locale, use one of the factory
    class methods:
    <blockquote>
    ````myString = NumberFormat.getInstance().format(myNumber);````
    </blockquote>
    If you are formatting multiple numbers, it is
    more efficient to get the format and use it multiple times so that
    the system doesn't have to fetch the information about the local
    language and country conventions multiple times.
    <blockquote>
    ````NumberFormat nf = NumberFormat.getInstance();
    for (int i = 0; i < myNumber.length; ++i) {
        output.println(nf.format(myNumber[i]) + "; ");`
    }```
    </blockquote>
    To format a number for a different Locale, specify it in the
    call to `getInstance`.
    <blockquote>
    ````NumberFormat nf = NumberFormat.getInstance(Locale.FRENCH);````
    </blockquote>
    
    If the locale contains "nu" (numbers) and/or "rg" (region override)
    <a href="../util/Locale.html#def_locale_extension">Unicode extensions</a>,
    the decimal digits, and/or the country used for formatting are overridden.
    If both "nu" and "rg" are specified, the decimal digits from the "nu"
    extension supersedes the implicit one from the "rg" extension.
    
    You can also use a `NumberFormat` to parse numbers:
    <blockquote>
    ````myNumber = nf.parse(myString);````
    </blockquote>
    Use `getInstance` or `getNumberInstance` to get the
    normal number format. Use `getIntegerInstance` to get an
    integer number format. Use `getCurrencyInstance` to get the
    currency number format. Use `getCompactNumberInstance` to get the
    compact number format to format a number in shorter form. For example,
    `2000` can be formatted as `"2K"` in
    java.util.Locale.US US locale. Use `getPercentInstance`
    to get a format for displaying percentages. With this format, a fraction
    like 0.53 is displayed as 53%.
    
    
    You can also control the display of numbers with such methods as
    `setMinimumFractionDigits`.
    If you want even more control over the format or parsing,
    or want to give your users more control,
    you can try casting the `NumberFormat` you get from the factory methods
    to a `DecimalFormat` or `CompactNumberFormat` depending on
    the factory method used. This will work for the vast majority of locales;
    just remember to put it in a `try` block in case you encounter
    an unusual one.
    
    
    NumberFormat and DecimalFormat are designed such that some controls
    work for formatting and others work for parsing.  The following is
    the detailed description for each these control methods,
    
    setParseIntegerOnly : only affects parsing, e.g.
    if True,  "3456.78" &rarr; 3456 (and leaves the parse position just after index 6)
    if False, "3456.78" &rarr; 3456.78 (and leaves the parse position just after index 8)
    This is independent of formatting.  If you want to not show a decimal point
    where there might be no digits after the decimal point, use
    setDecimalSeparatorAlwaysShown.
    
    setDecimalSeparatorAlwaysShown : only affects formatting, and only where
    there might be no digits after the decimal point, such as with a pattern
    like "#,##0.##", e.g.,
    if True,  3456.00 &rarr; "3,456."
    if False, 3456.00 &rarr; "3456"
    This is independent of parsing.  If you want parsing to stop at the decimal
    point, use setParseIntegerOnly.
    
    
    You can also use forms of the `parse` and `format`
    methods with `ParsePosition` and `FieldPosition` to
    allow you to:
    
    -  progressively parse through pieces of a string
    -  align the decimal point and other areas
    
    For example, you can align numbers in two ways:
    <ol>
    -  If you are using a monospaced font with spacing for alignment,
         you can pass the `FieldPosition` in your format call, with
         `field` = `INTEGER_FIELD`. On output,
         `getEndIndex` will be set to the offset between the
         last character of the integer and the decimal. Add
         (desiredSpaceCount - getEndIndex) spaces at the front of the string.
    
    -  If you are using proportional fonts,
         instead of padding with spaces, measure the width
         of the string in pixels from the start to `getEndIndex`.
         Then move the pen by
         (desiredPixelWidth - widthToAlignmentPoint) before drawing the text.
         It also works where there is no decimal, but possibly additional
         characters at the end, e.g., with parentheses in negative
         numbers: "(12)" for -12.
    </ol>
    
    <h2><a id="synchronization">Synchronization</a></h2>
    
    
    Number formats are generally not synchronized.
    It is recommended to create separate format instances for each thread.
    If multiple threads access a format concurrently, it must be synchronized
    externally.

    Author(s)
    - Helena Shih

    See
    - CompactNumberFormat

    Since
    - 1.1

    Unknown Tags
    - The .format(double, StringBuffer, FieldPosition),
    .format(long, StringBuffer, FieldPosition) and
    .parse(String, ParsePosition) methods may throw
    `NullPointerException`, if any of their parameter is `null`.
    The subclass may provide its own implementation and specification about
    `NullPointerException`.
    
    
    The default implementation provides rounding modes defined
    in java.math.RoundingMode for formatting numbers. It
    uses the java.math.RoundingMode.HALF_EVEN
    round half-even algorithm. To change the rounding mode use
    .setRoundingMode(java.math.RoundingMode) setRoundingMode.
    The `NumberFormat` returned by the static factory methods is
    configured to round floating point numbers using half-even
    rounding (see java.math.RoundingMode.HALF_EVEN
    RoundingMode.HALF_EVEN) for formatting.
    """

    INTEGER_FIELD = 0
    """
    Field constant used to construct a FieldPosition object. Signifies that
    the position of the integer part of a formatted number should be returned.

    See
    - java.text.FieldPosition
    """
    FRACTION_FIELD = 1
    """
    Field constant used to construct a FieldPosition object. Signifies that
    the position of the fraction part of a formatted number should be returned.

    See
    - java.text.FieldPosition
    """


    def format(self, number: "Object", toAppendTo: "StringBuffer", pos: "FieldPosition") -> "StringBuffer":
        """
        Formats a number and appends the resulting text to the given string
        buffer.
        The number can be of any subclass of java.lang.Number.
        
        This implementation extracts the number's value using
        java.lang.Number.longValue() for all integral type values that
        can be converted to `long` without loss of information,
        including `BigInteger` values with a
        java.math.BigInteger.bitLength() bit length of less than 64,
        and java.lang.Number.doubleValue() for all other types. It
        then calls
        .format(long,java.lang.StringBuffer,java.text.FieldPosition)
        or .format(double,java.lang.StringBuffer,java.text.FieldPosition).
        This may result in loss of magnitude information and precision for
        `BigInteger` and `BigDecimal` values.

        Arguments
        - number: the number to format
        - toAppendTo: the `StringBuffer` to which the formatted
                          text is to be appended
        - pos: keeps track on the position of the field within the
                          returned string. For example, for formatting a number
                          `1234567.89` in `Locale.US` locale,
                          if the given `fieldPosition` is
                          NumberFormat.INTEGER_FIELD, the begin index
                          and end index of `fieldPosition` will be set
                          to 0 and 9, respectively for the output string
                          `1,234,567.89`.

        Returns
        - the value passed in as `toAppendTo`

        Raises
        - IllegalArgumentException: if `number` is
                          null or not an instance of `Number`.
        - NullPointerException: if `toAppendTo` or
                          `pos` is null
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.FieldPosition
        """
        ...


    def parseObject(self, source: str, pos: "ParsePosition") -> "Object":
        """
        Parses text from a string to produce a `Number`.
        
        The method attempts to parse text starting at the index given by
        `pos`.
        If parsing succeeds, then the index of `pos` is updated
        to the index after the last character used (parsing does not necessarily
        use all characters up to the end of the string), and the parsed
        number is returned. The updated `pos` can be used to
        indicate the starting point for the next call to this method.
        If an error occurs, then the index of `pos` is not
        changed, the error index of `pos` is set to the index of
        the character where the error occurred, and null is returned.
        
        See the .parse(String, ParsePosition) method for more information
        on number parsing.

        Arguments
        - source: A `String`, part of which should be parsed.
        - pos: A `ParsePosition` object with index and error
                   index information as described above.

        Returns
        - A `Number` parsed from the string. In case of
                error, returns null.

        Raises
        - NullPointerException: if `source` or `pos` is null.
        """
        ...


    def format(self, number: float) -> str:
        """
        Specialization of format.

        Arguments
        - number: the double number to format

        Returns
        - the formatted String

        Raises
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.Format.format
        """
        ...


    def format(self, number: int) -> str:
        """
        Specialization of format.

        Arguments
        - number: the long number to format

        Returns
        - the formatted String

        Raises
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.Format.format
        """
        ...


    def format(self, number: float, toAppendTo: "StringBuffer", pos: "FieldPosition") -> "StringBuffer":
        """
        Specialization of format.

        Arguments
        - number: the double number to format
        - toAppendTo: the StringBuffer to which the formatted text is to be
                          appended
        - pos: keeps track on the position of the field within the
                          returned string. For example, for formatting a number
                          `1234567.89` in `Locale.US` locale,
                          if the given `fieldPosition` is
                          NumberFormat.INTEGER_FIELD, the begin index
                          and end index of `fieldPosition` will be set
                          to 0 and 9, respectively for the output string
                          `1,234,567.89`.

        Returns
        - the formatted StringBuffer

        Raises
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.Format.format
        """
        ...


    def format(self, number: int, toAppendTo: "StringBuffer", pos: "FieldPosition") -> "StringBuffer":
        """
        Specialization of format.

        Arguments
        - number: the long number to format
        - toAppendTo: the StringBuffer to which the formatted text is to be
                          appended
        - pos: keeps track on the position of the field within the
                          returned string. For example, for formatting a number
                          `123456789` in `Locale.US` locale,
                          if the given `fieldPosition` is
                          NumberFormat.INTEGER_FIELD, the begin index
                          and end index of `fieldPosition` will be set
                          to 0 and 11, respectively for the output string
                          `123,456,789`.

        Returns
        - the formatted StringBuffer

        Raises
        - ArithmeticException: if rounding is needed with rounding
                          mode being set to RoundingMode.UNNECESSARY

        See
        - java.text.Format.format
        """
        ...


    def parse(self, source: str, parsePosition: "ParsePosition") -> "Number":
        """
        Returns a Long if possible (e.g., within the range [Long.MIN_VALUE,
        Long.MAX_VALUE] and with no decimals), otherwise a Double.
        If IntegerOnly is set, will stop at a decimal
        point (or equivalent; e.g., for rational numbers "1 2/3", will stop
        after the 1).
        Does not throw an exception; if no object can be parsed, index is
        unchanged!

        Arguments
        - source: the String to parse
        - parsePosition: the parse position

        Returns
        - the parsed value

        See
        - java.text.Format.parseObject
        """
        ...


    def parse(self, source: str) -> "Number":
        """
        Parses text from the beginning of the given string to produce a number.
        The method may not use the entire text of the given string.
        
        See the .parse(String, ParsePosition) method for more information
        on number parsing.

        Arguments
        - source: A `String` whose beginning should be parsed.

        Returns
        - A `Number` parsed from the string.

        Raises
        - ParseException: if the beginning of the specified string
                   cannot be parsed.
        """
        ...


    def isParseIntegerOnly(self) -> bool:
        """
        Returns True if this format will parse numbers as integers only.
        For example in the English locale, with ParseIntegerOnly True, the
        string "1234." would be parsed as the integer value 1234 and parsing
        would stop at the "." character.  Of course, the exact format accepted
        by the parse operation is locale dependent and determined by sub-classes
        of NumberFormat.

        Returns
        - `True` if numbers should be parsed as integers only;
                `False` otherwise
        """
        ...


    def setParseIntegerOnly(self, value: bool) -> None:
        """
        Sets whether or not numbers should be parsed as integers only.

        Arguments
        - value: `True` if numbers should be parsed as integers only;
                     `False` otherwise

        See
        - .isParseIntegerOnly
        """
        ...


    @staticmethod
    def getInstance() -> "NumberFormat":
        """
        Returns a general-purpose number format for the current default
        java.util.Locale.Category.FORMAT FORMAT locale.
        This is the same as calling
        .getNumberInstance() getNumberInstance().

        Returns
        - the `NumberFormat` instance for general-purpose number
        formatting
        """
        ...


    @staticmethod
    def getInstance(inLocale: "Locale") -> "NumberFormat":
        """
        Returns a general-purpose number format for the specified locale.
        This is the same as calling
        .getNumberInstance(java.util.Locale) getNumberInstance(inLocale).

        Arguments
        - inLocale: the desired locale

        Returns
        - the `NumberFormat` instance for general-purpose number
        formatting
        """
        ...


    @staticmethod
    def getNumberInstance() -> "NumberFormat":
        """
        Returns a general-purpose number format for the current default
        java.util.Locale.Category.FORMAT FORMAT locale.
        This is equivalent to calling
        .getNumberInstance(Locale)
            getNumberInstance(Locale.getDefault(Locale.Category.FORMAT)).

        Returns
        - the `NumberFormat` instance for general-purpose number
        formatting

        See
        - java.util.Locale.Category.FORMAT
        """
        ...


    @staticmethod
    def getNumberInstance(inLocale: "Locale") -> "NumberFormat":
        """
        Returns a general-purpose number format for the specified locale.

        Arguments
        - inLocale: the desired locale

        Returns
        - the `NumberFormat` instance for general-purpose number
        formatting
        """
        ...


    @staticmethod
    def getIntegerInstance() -> "NumberFormat":
        """
        Returns an integer number format for the current default
        java.util.Locale.Category.FORMAT FORMAT locale. The
        returned number format is configured to round floating point numbers
        to the nearest integer using half-even rounding (see java.math.RoundingMode.HALF_EVEN RoundingMode.HALF_EVEN) for formatting,
        and to parse only the integer part of an input string (see .isParseIntegerOnly isParseIntegerOnly).
        This is equivalent to calling
        .getIntegerInstance(Locale)
            getIntegerInstance(Locale.getDefault(Locale.Category.FORMAT)).

        Returns
        - a number format for integer values

        See
        - java.util.Locale.Category.FORMAT

        Since
        - 1.4
        """
        ...


    @staticmethod
    def getIntegerInstance(inLocale: "Locale") -> "NumberFormat":
        """
        Returns an integer number format for the specified locale. The
        returned number format is configured to round floating point numbers
        to the nearest integer using half-even rounding (see java.math.RoundingMode.HALF_EVEN RoundingMode.HALF_EVEN) for formatting,
        and to parse only the integer part of an input string (see .isParseIntegerOnly isParseIntegerOnly).

        Arguments
        - inLocale: the desired locale

        Returns
        - a number format for integer values

        See
        - .getRoundingMode()

        Since
        - 1.4
        """
        ...


    @staticmethod
    def getCurrencyInstance() -> "NumberFormat":
        """
        Returns a currency format for the current default
        java.util.Locale.Category.FORMAT FORMAT locale.
        This is equivalent to calling
        .getCurrencyInstance(Locale)
            getCurrencyInstance(Locale.getDefault(Locale.Category.FORMAT)).

        Returns
        - the `NumberFormat` instance for currency formatting

        See
        - java.util.Locale.Category.FORMAT
        """
        ...


    @staticmethod
    def getCurrencyInstance(inLocale: "Locale") -> "NumberFormat":
        """
        Returns a currency format for the specified locale.
        
        If the specified locale contains the "`cf`" (
        <a href="https://www.unicode.org/reports/tr35/tr35.html#UnicodeCurrencyFormatIdentifier">
        currency format style</a>)
        <a href="../util/Locale.html#def_locale_extension">Unicode extension</a>,
        the returned currency format uses the style if it is available.
        Otherwise, the style uses the default "`standard`" currency format.
        For example, if the style designates "`account`", negative
        currency amounts use a pair of parentheses in some locales.

        Arguments
        - inLocale: the desired locale

        Returns
        - the `NumberFormat` instance for currency formatting
        """
        ...


    @staticmethod
    def getPercentInstance() -> "NumberFormat":
        """
        Returns a percentage format for the current default
        java.util.Locale.Category.FORMAT FORMAT locale.
        This is equivalent to calling
        .getPercentInstance(Locale)
            getPercentInstance(Locale.getDefault(Locale.Category.FORMAT)).

        Returns
        - the `NumberFormat` instance for percentage formatting

        See
        - java.util.Locale.Category.FORMAT
        """
        ...


    @staticmethod
    def getPercentInstance(inLocale: "Locale") -> "NumberFormat":
        """
        Returns a percentage format for the specified locale.

        Arguments
        - inLocale: the desired locale

        Returns
        - the `NumberFormat` instance for percentage formatting
        """
        ...


    @staticmethod
    def getCompactNumberInstance() -> "NumberFormat":
        """
        Returns a compact number format for the default
        java.util.Locale.Category.FORMAT FORMAT locale with
        NumberFormat.Style.SHORT "SHORT" format style.

        Returns
        - A `NumberFormat` instance for compact number
                formatting

        See
        - java.util.Locale.Category.FORMAT

        Since
        - 12
        """
        ...


    @staticmethod
    def getCompactNumberInstance(locale: "Locale", formatStyle: "NumberFormat.Style") -> "NumberFormat":
        """
        Returns a compact number format for the specified java.util.Locale locale
        and NumberFormat.Style formatStyle.

        Arguments
        - locale: the desired locale
        - formatStyle: the style for formatting a number

        Returns
        - A `NumberFormat` instance for compact number
                formatting

        Raises
        - NullPointerException: if `locale` or `formatStyle`
                                     is `null`

        See
        - java.util.Locale

        Since
        - 12
        """
        ...


    @staticmethod
    def getAvailableLocales() -> list["Locale"]:
        """
        Returns an array of all locales for which the
        `get*Instance` methods of this class can return
        localized instances.
        The returned array represents the union of locales supported by the Java
        runtime and by installed
        java.text.spi.NumberFormatProvider NumberFormatProvider implementations.
        It must contain at least a `Locale` instance equal to
        java.util.Locale.US Locale.US.

        Returns
        - An array of locales for which localized
                `NumberFormat` instances are available.
        """
        ...


    def hashCode(self) -> int:
        """
        Overrides hashCode.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Overrides equals.
        """
        ...


    def clone(self) -> "Object":
        """
        Overrides Cloneable.
        """
        ...


    def isGroupingUsed(self) -> bool:
        """
        Returns True if grouping is used in this format. For example, in the
        English locale, with grouping on, the number 1234567 might be formatted
        as "1,234,567". The grouping separator as well as the size of each group
        is locale dependent and is determined by sub-classes of NumberFormat.

        Returns
        - `True` if grouping is used;
                `False` otherwise

        See
        - .setGroupingUsed
        """
        ...


    def setGroupingUsed(self, newValue: bool) -> None:
        """
        Set whether or not grouping will be used in this format.

        Arguments
        - newValue: `True` if grouping is used;
                        `False` otherwise

        See
        - .isGroupingUsed
        """
        ...


    def getMaximumIntegerDigits(self) -> int:
        """
        Returns the maximum number of digits allowed in the integer portion of a
        number.

        Returns
        - the maximum number of digits

        See
        - .setMaximumIntegerDigits
        """
        ...


    def setMaximumIntegerDigits(self, newValue: int) -> None:
        """
        Sets the maximum number of digits allowed in the integer portion of a
        number. maximumIntegerDigits must be &ge; minimumIntegerDigits.  If the
        new value for maximumIntegerDigits is less than the current value
        of minimumIntegerDigits, then minimumIntegerDigits will also be set to
        the new value.

        Arguments
        - newValue: the maximum number of integer digits to be shown; if
        less than zero, then zero is used. The concrete subclass may enforce an
        upper limit to this value appropriate to the numeric type being formatted.

        See
        - .getMaximumIntegerDigits
        """
        ...


    def getMinimumIntegerDigits(self) -> int:
        """
        Returns the minimum number of digits allowed in the integer portion of a
        number.

        Returns
        - the minimum number of digits

        See
        - .setMinimumIntegerDigits
        """
        ...


    def setMinimumIntegerDigits(self, newValue: int) -> None:
        """
        Sets the minimum number of digits allowed in the integer portion of a
        number. minimumIntegerDigits must be &le; maximumIntegerDigits.  If the
        new value for minimumIntegerDigits exceeds the current value
        of maximumIntegerDigits, then maximumIntegerDigits will also be set to
        the new value

        Arguments
        - newValue: the minimum number of integer digits to be shown; if
        less than zero, then zero is used. The concrete subclass may enforce an
        upper limit to this value appropriate to the numeric type being formatted.

        See
        - .getMinimumIntegerDigits
        """
        ...


    def getMaximumFractionDigits(self) -> int:
        """
        Returns the maximum number of digits allowed in the fraction portion of a
        number.

        Returns
        - the maximum number of digits.

        See
        - .setMaximumFractionDigits
        """
        ...


    def setMaximumFractionDigits(self, newValue: int) -> None:
        """
        Sets the maximum number of digits allowed in the fraction portion of a
        number. maximumFractionDigits must be &ge; minimumFractionDigits.  If the
        new value for maximumFractionDigits is less than the current value
        of minimumFractionDigits, then minimumFractionDigits will also be set to
        the new value.

        Arguments
        - newValue: the maximum number of fraction digits to be shown; if
        less than zero, then zero is used. The concrete subclass may enforce an
        upper limit to this value appropriate to the numeric type being formatted.

        See
        - .getMaximumFractionDigits
        """
        ...


    def getMinimumFractionDigits(self) -> int:
        """
        Returns the minimum number of digits allowed in the fraction portion of a
        number.

        Returns
        - the minimum number of digits

        See
        - .setMinimumFractionDigits
        """
        ...


    def setMinimumFractionDigits(self, newValue: int) -> None:
        """
        Sets the minimum number of digits allowed in the fraction portion of a
        number. minimumFractionDigits must be &le; maximumFractionDigits.  If the
        new value for minimumFractionDigits exceeds the current value
        of maximumFractionDigits, then maximumFractionDigits will also be set to
        the new value

        Arguments
        - newValue: the minimum number of fraction digits to be shown; if
        less than zero, then zero is used. The concrete subclass may enforce an
        upper limit to this value appropriate to the numeric type being formatted.

        See
        - .getMinimumFractionDigits
        """
        ...


    def getCurrency(self) -> "Currency":
        """
        Gets the currency used by this number format when formatting
        currency values. The initial value is derived in a locale dependent
        way. The returned value may be null if no valid
        currency could be determined and no currency has been set using
        .setCurrency(java.util.Currency) setCurrency.
        
        The default implementation throws
        `UnsupportedOperationException`.

        Returns
        - the currency used by this number format, or `null`

        Raises
        - UnsupportedOperationException: if the number format class
        doesn't implement currency formatting

        Since
        - 1.4
        """
        ...


    def setCurrency(self, currency: "Currency") -> None:
        """
        Sets the currency used by this number format when formatting
        currency values. This does not update the minimum or maximum
        number of fraction digits used by the number format.
        
        The default implementation throws
        `UnsupportedOperationException`.

        Arguments
        - currency: the new currency to be used by this number format

        Raises
        - UnsupportedOperationException: if the number format class
        doesn't implement currency formatting
        - NullPointerException: if `currency` is null

        Since
        - 1.4
        """
        ...


    def getRoundingMode(self) -> "RoundingMode":
        """
        Gets the java.math.RoundingMode used in this NumberFormat.
        The default implementation of this method in NumberFormat
        always throws java.lang.UnsupportedOperationException.
        Subclasses which handle different rounding modes should override
        this method.

        Returns
        - The `RoundingMode` used for this NumberFormat.

        Raises
        - UnsupportedOperationException: The default implementation
            always throws this exception

        See
        - .setRoundingMode(RoundingMode)

        Since
        - 1.6
        """
        ...


    def setRoundingMode(self, roundingMode: "RoundingMode") -> None:
        """
        Sets the java.math.RoundingMode used in this NumberFormat.
        The default implementation of this method in NumberFormat always
        throws java.lang.UnsupportedOperationException.
        Subclasses which handle different rounding modes should override
        this method.

        Arguments
        - roundingMode: The `RoundingMode` to be used

        Raises
        - UnsupportedOperationException: The default implementation
            always throws this exception
        - NullPointerException: if `roundingMode` is null

        See
        - .getRoundingMode()

        Since
        - 1.6
        """
        ...


    class Field(Field):
        """
        Defines constants that are used as attribute keys in the
        `AttributedCharacterIterator` returned
        from `NumberFormat.formatToCharacterIterator` and as
        field identifiers in `FieldPosition`.

        Since
        - 1.4
        """

        INTEGER = Field("integer")
        """
        Constant identifying the integer field.
        """
        FRACTION = Field("fraction")
        """
        Constant identifying the fraction field.
        """
        EXPONENT = Field("exponent")
        """
        Constant identifying the exponent field.
        """
        DECIMAL_SEPARATOR = Field("decimal separator")
        """
        Constant identifying the decimal separator field.
        """
        SIGN = Field("sign")
        """
        Constant identifying the sign field.
        """
        GROUPING_SEPARATOR = Field("grouping separator")
        """
        Constant identifying the grouping separator field.
        """
        EXPONENT_SYMBOL = Field("exponent symbol")
        """
        Constant identifying the exponent symbol field.
        """
        PERCENT = Field("percent")
        """
        Constant identifying the percent field.
        """
        PERMILLE = Field("per mille")
        """
        Constant identifying the permille field.
        """
        CURRENCY = Field("currency")
        """
        Constant identifying the currency field.
        """
        EXPONENT_SIGN = Field("exponent sign")
        """
        Constant identifying the exponent sign field.
        """
        PREFIX = Field("prefix")
        """
        Constant identifying the prefix field.

        Since
        - 12
        """
        SUFFIX = Field("suffix")
        """
        Constant identifying the suffix field.

        Since
        - 12
        """


    class Style(Enum):
        """
        A number format style.
        
        `Style` is an enum which represents the style for formatting
        a number within a given `NumberFormat` instance.

        See
        - NumberFormat.getCompactNumberInstance(Locale, Style)

        Since
        - 12
        """

        SHORT = 0
        """
        The `SHORT` number format style.
        """
        LONG = 1
        """
        The `LONG` number format style.
        """



"""
Python module generated from Java source file org.bukkit.event.player.PlayerCommandPreprocessEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerCommandPreprocessEvent(PlayerEvent, Cancellable):
    """
    This event is called whenever a player runs a command (by placing a slash
    at the start of their message). It is called early in the command handling
    process, and modifications in this event (via .setMessage(String))
    will be shown in the behavior.
    
    Many plugins will have **no use for this event**, and you should
    attempt to avoid using it if it is not necessary.
    
    Some examples of valid uses for this event are:
    
    - Logging executed commands to a separate file
    - Variable substitution. For example, replacing
        `${nearbyPlayer}` with the name of the nearest other
        player, or simulating the `@a` and `@p`
        decorators used by Command Blocks in plugins that do not handle it.
    - Conditionally blocking commands belonging to other plugins. For
        example, blocking the use of the `/home` command in a
        combat arena.
    - Per-sender command aliases. For example, after a player runs the
        command `/calias cr gamemode creative`, the next time they
        run `/cr`, it gets replaced into
        `/gamemode creative`. (Global command aliases should be
        done by registering the alias.)
    
    
    Examples of incorrect uses are:
    
    - Using this event to run command logic
    
    
    If the event is cancelled, processing of the command will halt.
    
    The state of whether or not there is a slash (`/`) at the
    beginning of the message should be preserved. If a slash is added or
    removed, unexpected behavior may result.
    """

    def __init__(self, player: "Player", message: str):
        ...


    def __init__(self, player: "Player", message: str, recipients: set["Player"]):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getMessage(self) -> str:
        """
        Gets the command that the player is attempting to send.
        
        All commands begin with a special character; implementations do not
        consider the first character when executing the content.

        Returns
        - Message the player is attempting to send
        """
        ...


    def setMessage(self, command: str) -> None:
        """
        Sets the command that the player will send.
        
        All commands begin with a special character; implementations do not
        consider the first character when executing the content.

        Arguments
        - command: New message that the player will send

        Raises
        - IllegalArgumentException: if command is null or empty
        """
        ...


    def setPlayer(self, player: "Player") -> None:
        """
        Sets the player that this command will be executed as.

        Arguments
        - player: New player which this event will execute as

        Raises
        - IllegalArgumentException: if the player provided is null
        """
        ...


    def getRecipients(self) -> set["Player"]:
        """
        Gets a set of recipients that this chat message will be displayed to.
        
        The set returned is not guaranteed to be mutable and may auto-populate
        on access. Any listener accessing the returned set should be aware that
        it may reduce performance for a lazy set implementation. Listeners
        should be aware that modifying the list may throw UnsupportedOperationException if the event caller provides an
        unmodifiable set.

        Returns
        - All Players who will see this chat message

        Deprecated
        - This method is provided for backward compatibility with no
            guarantee to the effect of viewing or modifying the set.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.primitives.UnsignedBytes

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.primitives import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.lang.reflect import Field
from java.security import AccessController
from java.security import PrivilegedActionException
from java.security import PrivilegedExceptionAction
from java.util import Arrays
from java.util import Comparator
from sun.misc import Unsafe
from typing import Any, Callable, Iterable, Tuple


class UnsignedBytes:
    """
    Static utility methods pertaining to `byte` primitives that interpret values as
    *unsigned* (that is, any negative value `b` is treated as the positive value `256 + b`). The corresponding methods that treat the values as signed are found in SignedBytes, and the methods for which signedness is not an issue are in Bytes.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/PrimitivesExplained">primitive utilities</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 1.0
    """

    MAX_POWER_OF_TWO = (byte) 0x80
    """
    The largest power of two that can be represented as an unsigned `byte`.

    Since
    - 10.0
    """
    MAX_VALUE = (byte) 0xFF
    """
    The largest value that fits into an unsigned byte.

    Since
    - 13.0
    """


    @staticmethod
    def toInt(value: int) -> int:
        """
        Returns the value of the given byte as an integer, when treated as unsigned. That is, returns
        `value + 256` if `value` is negative; `value` itself otherwise.
        
        **Java 8+ users:** use Byte.toUnsignedInt(byte) instead.

        Since
        - 6.0
        """
        ...


    @staticmethod
    def checkedCast(value: int) -> int:
        """
        Returns the `byte` value that, when treated as unsigned, is equal to `value`, if
        possible.

        Arguments
        - value: a value between 0 and 255 inclusive

        Returns
        - the `byte` value that, when treated as unsigned, equals `value`

        Raises
        - IllegalArgumentException: if `value` is negative or greater than 255
        """
        ...


    @staticmethod
    def saturatedCast(value: int) -> int:
        """
        Returns the `byte` value that, when treated as unsigned, is nearest in value to `value`.

        Arguments
        - value: any `long` value

        Returns
        - `(byte) 255` if `value >= 255`, `(byte) 0` if `value <= 0`, and
            `value` cast to `byte` otherwise
        """
        ...


    @staticmethod
    def compare(a: int, b: int) -> int:
        """
        Compares the two specified `byte` values, treating them as unsigned values between 0 and
        255 inclusive. For example, `(byte) -127` is considered greater than `(byte) 127`
        because it is seen as having the value of positive `129`.

        Arguments
        - a: the first `byte` to compare
        - b: the second `byte` to compare

        Returns
        - a negative value if `a` is less than `b`; a positive value if `a` is
            greater than `b`; or zero if they are equal
        """
        ...


    @staticmethod
    def min(*array: Tuple[int, ...]) -> int:
        """
        Returns the least value present in `array`, treating values as unsigned.

        Arguments
        - array: a *nonempty* array of `byte` values

        Returns
        - the value present in `array` that is less than or equal to every other value in
            the array according to .compare

        Raises
        - IllegalArgumentException: if `array` is empty
        """
        ...


    @staticmethod
    def max(*array: Tuple[int, ...]) -> int:
        """
        Returns the greatest value present in `array`, treating values as unsigned.

        Arguments
        - array: a *nonempty* array of `byte` values

        Returns
        - the value present in `array` that is greater than or equal to every other value
            in the array according to .compare

        Raises
        - IllegalArgumentException: if `array` is empty
        """
        ...


    @staticmethod
    def toString(x: int) -> str:
        """
        Returns a string representation of x, where x is treated as unsigned.

        Since
        - 13.0
        """
        ...


    @staticmethod
    def toString(x: int, radix: int) -> str:
        """
        Returns a string representation of `x` for the given radix, where `x` is treated as
        unsigned.

        Arguments
        - x: the value to convert to a string.
        - radix: the radix to use while working with `x`

        Raises
        - IllegalArgumentException: if `radix` is not between Character.MIN_RADIX
            and Character.MAX_RADIX.

        Since
        - 13.0
        """
        ...


    @staticmethod
    def parseUnsignedByte(string: str) -> int:
        """
        Returns the unsigned `byte` value represented by the given decimal string.

        Raises
        - NumberFormatException: if the string does not contain a valid unsigned `byte`
            value
        - NullPointerException: if `string` is null (in contrast to Byte.parseByte(String))

        Since
        - 13.0
        """
        ...


    @staticmethod
    def parseUnsignedByte(string: str, radix: int) -> int:
        """
        Returns the unsigned `byte` value represented by a string with the given radix.

        Arguments
        - string: the string containing the unsigned `byte` representation to be parsed.
        - radix: the radix to use while parsing `string`

        Raises
        - NumberFormatException: if the string does not contain a valid unsigned `byte` with
            the given radix, or if `radix` is not between Character.MIN_RADIX and Character.MAX_RADIX.
        - NullPointerException: if `string` is null (in contrast to Byte.parseByte(String))

        Since
        - 13.0
        """
        ...


    @staticmethod
    def join(separator: str, *array: Tuple[int, ...]) -> str:
        """
        Returns a string containing the supplied `byte` values separated by `separator`.
        For example, `join(":", (byte) 1, (byte) 2, (byte) 255)` returns the string `"1:2:255"`.

        Arguments
        - separator: the text that should appear between consecutive values in the resulting string
            (but not at the start or end)
        - array: an array of `byte` values, possibly empty
        """
        ...


    @staticmethod
    def lexicographicalComparator() -> "Comparator"[list[int]]:
        """
        Returns a comparator that compares two `byte` arrays <a
        href="http://en.wikipedia.org/wiki/Lexicographical_order">lexicographically</a>. That is, it
        compares, using .compare(byte, byte)), the first pair of values that follow any common
        prefix, or when one array is a prefix of the other, treats the shorter array as the lesser. For
        example, `[] < [0x01] < [0x01, 0x7F] < [0x01, 0x80] < [0x02]`. Values are treated as
        unsigned.
        
        The returned comparator is inconsistent with Object.equals(Object) (since arrays
        support only identity equality), but it is consistent with java.util.Arrays.equals(byte[], byte[]).

        Since
        - 2.0
        """
        ...


    @staticmethod
    def sort(array: list[int]) -> None:
        """
        Sorts the array, treating its elements as unsigned bytes.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def sort(array: list[int], fromIndex: int, toIndex: int) -> None:
        """
        Sorts the array between `fromIndex` inclusive and `toIndex` exclusive, treating its
        elements as unsigned bytes.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def sortDescending(array: list[int]) -> None:
        """
        Sorts the elements of `array` in descending order, interpreting them as unsigned 8-bit
        integers.

        Since
        - 23.1
        """
        ...


    @staticmethod
    def sortDescending(array: list[int], fromIndex: int, toIndex: int) -> None:
        """
        Sorts the elements of `array` between `fromIndex` inclusive and `toIndex`
        exclusive in descending order, interpreting them as unsigned 8-bit integers.

        Since
        - 23.1
        """
        ...



"""
Python module generated from Java source file com.google.common.base.Predicates

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import *
from java.io import Serializable
from java.util import Arrays
from java.util.regex import Pattern
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Predicates:
    """
    Static utility methods pertaining to `Predicate` instances.
    
    All methods return serializable predicates as long as they're given serializable parameters.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/FunctionalExplained">the use of `Predicate`</a>.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    @staticmethod
    def alwaysTrue() -> "Predicate"["T"]:
        """
        Returns a predicate that always evaluates to `True`.
        """
        ...


    @staticmethod
    def alwaysFalse() -> "Predicate"["T"]:
        """
        Returns a predicate that always evaluates to `False`.
        """
        ...


    @staticmethod
    def isNull() -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if the object reference being tested is
        null.
        """
        ...


    @staticmethod
    def notNull() -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if the object reference being tested is not
        null.
        """
        ...


    @staticmethod
    def not(predicate: "Predicate"["T"]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if the given predicate evaluates to `False`.
        """
        ...


    @staticmethod
    def and(components: Iterable["Predicate"["T"]]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if each of its components evaluates to
        `True`. The components are evaluated in order, and evaluation will be "short-circuited"
        as soon as a False predicate is found. It defensively copies the iterable passed in, so future
        changes to it won't alter the behavior of this predicate. If `components` is empty, the
        returned predicate will always evaluate to `True`.
        """
        ...


    @staticmethod
    def and(*components: Tuple["Predicate"["T"], ...]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if each of its components evaluates to
        `True`. The components are evaluated in order, and evaluation will be "short-circuited"
        as soon as a False predicate is found. It defensively copies the array passed in, so future
        changes to it won't alter the behavior of this predicate. If `components` is empty, the
        returned predicate will always evaluate to `True`.
        """
        ...


    @staticmethod
    def and(first: "Predicate"["T"], second: "Predicate"["T"]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if both of its components evaluate to `True`. The components are evaluated in order, and evaluation will be "short-circuited" as soon
        as a False predicate is found.
        """
        ...


    @staticmethod
    def or(components: Iterable["Predicate"["T"]]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if any one of its components evaluates to
        `True`. The components are evaluated in order, and evaluation will be "short-circuited"
        as soon as a True predicate is found. It defensively copies the iterable passed in, so future
        changes to it won't alter the behavior of this predicate. If `components` is empty, the
        returned predicate will always evaluate to `False`.
        """
        ...


    @staticmethod
    def or(*components: Tuple["Predicate"["T"], ...]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if any one of its components evaluates to
        `True`. The components are evaluated in order, and evaluation will be "short-circuited"
        as soon as a True predicate is found. It defensively copies the array passed in, so future
        changes to it won't alter the behavior of this predicate. If `components` is empty, the
        returned predicate will always evaluate to `False`.
        """
        ...


    @staticmethod
    def or(first: "Predicate"["T"], second: "Predicate"["T"]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if either of its components evaluates to
        `True`. The components are evaluated in order, and evaluation will be "short-circuited"
        as soon as a True predicate is found.
        """
        ...


    @staticmethod
    def equalTo(target: "T") -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if the object being tested `equals()`
        the given target or both are null.
        """
        ...


    @staticmethod
    def instanceOf(clazz: type[Any]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if the object being tested is an instance of
        the given class. If the object being tested is `null` this predicate evaluates to `False`.
        
        If you want to filter an `Iterable` to narrow its type, consider using com.google.common.collect.Iterables.filter(Iterable, Class) in preference.
        
        **Warning:** contrary to the typical assumptions about predicates (as documented at
        Predicate.apply), the returned predicate may not be *consistent with equals*. For
        example, `instanceOf(ArrayList.class)` will yield different results for the two equal
        instances `Lists.newArrayList(1)` and `Arrays.asList(1)`.
        """
        ...


    @staticmethod
    def subtypeOf(clazz: type[Any]) -> "Predicate"[type[Any]]:
        """
        Returns a predicate that evaluates to `True` if the class being tested is assignable to
        (is a subtype of) `clazz`. Example:
        
        ````List<Class<?>> classes = Arrays.asList(
            Object.class, String.class, Number.class, Long.class);
        return Iterables.filter(classes, subtypeOf(Number.class));````
        
        The code above returns an iterable containing `Number.class` and `Long.class`.

        Since
        - 20.0 (since 10.0 under the incorrect name `assignableFrom`)
        """
        ...


    @staticmethod
    def in(target: Iterable["T"]) -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to `True` if the object reference being tested is a
        member of the given collection. It does not defensively copy the collection passed in, so
        future changes to it will alter the behavior of the predicate.
        
        This method can technically accept any `Collection<?>`, but using a typed collection
        helps prevent bugs. This approach doesn't block any potential users since it is always possible
        to use `Predicates.<Object>in()`.

        Arguments
        - target: the collection that may contain the function input
        """
        ...


    @staticmethod
    def compose(predicate: "Predicate"["B"], function: "Function"["A", "B"]) -> "Predicate"["A"]:
        """
        Returns the composition of a function and a predicate. For every `x`, the generated
        predicate returns `predicate(function(x))`.

        Returns
        - the composition of the provided function and predicate
        """
        ...


    @staticmethod
    def containsPattern(pattern: str) -> "Predicate"["CharSequence"]:
        """
        Returns a predicate that evaluates to `True` if the `CharSequence` being tested
        contains any match for the given regular expression pattern. The test used is equivalent to
        `Pattern.compile(pattern).matcher(arg).find()`

        Raises
        - IllegalArgumentException: if the pattern is invalid

        Since
        - 3.0
        """
        ...


    @staticmethod
    def contains(pattern: "Pattern") -> "Predicate"["CharSequence"]:
        """
        Returns a predicate that evaluates to `True` if the `CharSequence` being tested
        contains any match for the given regular expression pattern. The test used is equivalent to
        `pattern.matcher(arg).find()`

        Since
        - 3.0
        """
        ...



"""
Python module generated from Java source file com.google.common.primitives.UnsignedLong

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import Serializable
from java.math import BigInteger
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class UnsignedLong(Number, Comparable, Serializable):
    """
    A wrapper class for unsigned `long` values, supporting arithmetic operations.
    
    In some cases, when speed is more important than code readability, it may be faster simply to
    treat primitive `long` values as unsigned, using the methods from UnsignedLongs.
    
    See the Guava User Guide article on <a
    href="https://github.com/google/guava/wiki/PrimitivesExplained#unsigned-support">unsigned
    primitive utilities</a>.

    Author(s)
    - Colin Evans

    Since
    - 11.0
    """

    ZERO = UnsignedLong(0)
    ONE = UnsignedLong(1)
    MAX_VALUE = UnsignedLong(-1L)


    @staticmethod
    def fromLongBits(bits: int) -> "UnsignedLong":
        """
        Returns an `UnsignedLong` corresponding to a given bit representation. The argument is
        interpreted as an unsigned 64-bit value. Specifically, the sign bit of `bits` is
        interpreted as a normal bit, and all other bits are treated as usual.
        
        If the argument is nonnegative, the returned result will be equal to `bits`,
        otherwise, the result will be equal to `2^64 + bits`.
        
        To represent decimal constants less than `2^63`, consider .valueOf(long)
        instead.

        Since
        - 14.0
        """
        ...


    @staticmethod
    def valueOf(value: int) -> "UnsignedLong":
        """
        Returns an `UnsignedLong` representing the same value as the specified `long`.

        Raises
        - IllegalArgumentException: if `value` is negative

        Since
        - 14.0
        """
        ...


    @staticmethod
    def valueOf(value: "BigInteger") -> "UnsignedLong":
        """
        Returns a `UnsignedLong` representing the same value as the specified `BigInteger`.
        This is the inverse operation of .bigIntegerValue().

        Raises
        - IllegalArgumentException: if `value` is negative or `value >= 2^64`
        """
        ...


    @staticmethod
    def valueOf(string: str) -> "UnsignedLong":
        """
        Returns an `UnsignedLong` holding the value of the specified `String`, parsed as an
        unsigned `long` value.

        Raises
        - NumberFormatException: if the string does not contain a parsable unsigned `long`
            value
        """
        ...


    @staticmethod
    def valueOf(string: str, radix: int) -> "UnsignedLong":
        """
        Returns an `UnsignedLong` holding the value of the specified `String`, parsed as an
        unsigned `long` value in the specified radix.

        Raises
        - NumberFormatException: if the string does not contain a parsable unsigned `long`
            value, or `radix` is not between Character.MIN_RADIX and Character.MAX_RADIX
        """
        ...


    def plus(self, val: "UnsignedLong") -> "UnsignedLong":
        """
        Returns the result of adding this and `val`. If the result would have more than 64 bits,
        returns the low 64 bits of the result.

        Since
        - 14.0
        """
        ...


    def minus(self, val: "UnsignedLong") -> "UnsignedLong":
        """
        Returns the result of subtracting this and `val`. If the result would have more than 64
        bits, returns the low 64 bits of the result.

        Since
        - 14.0
        """
        ...


    def times(self, val: "UnsignedLong") -> "UnsignedLong":
        """
        Returns the result of multiplying this and `val`. If the result would have more than 64
        bits, returns the low 64 bits of the result.

        Since
        - 14.0
        """
        ...


    def dividedBy(self, val: "UnsignedLong") -> "UnsignedLong":
        """
        Returns the result of dividing this by `val`.

        Since
        - 14.0
        """
        ...


    def mod(self, val: "UnsignedLong") -> "UnsignedLong":
        """
        Returns this modulo `val`.

        Since
        - 14.0
        """
        ...


    def intValue(self) -> int:
        """
        Returns the value of this `UnsignedLong` as an `int`.
        """
        ...


    def longValue(self) -> int:
        """
        Returns the value of this `UnsignedLong` as a `long`. This is an inverse operation
        to .fromLongBits.
        
        Note that if this `UnsignedLong` holds a value `>= 2^63`, the returned value
        will be equal to `this - 2^64`.
        """
        ...


    def floatValue(self) -> float:
        """
        Returns the value of this `UnsignedLong` as a `float`, analogous to a widening
        primitive conversion from `long` to `float`, and correctly rounded.
        """
        ...


    def doubleValue(self) -> float:
        """
        Returns the value of this `UnsignedLong` as a `double`, analogous to a widening
        primitive conversion from `long` to `double`, and correctly rounded.
        """
        ...


    def bigIntegerValue(self) -> "BigInteger":
        """
        Returns the value of this `UnsignedLong` as a BigInteger.
        """
        ...


    def compareTo(self, o: "UnsignedLong") -> int:
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def toString(self) -> str:
        """
        Returns a string representation of the `UnsignedLong` value, in base 10.
        """
        ...


    def toString(self, radix: int) -> str:
        """
        Returns a string representation of the `UnsignedLong` value, in base `radix`. If
        `radix < Character.MIN_RADIX` or `radix > Character.MAX_RADIX`, the radix `10` is used.
        """
        ...



"""
Python module generated from Java source file java.io.ObjectOutput

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class ObjectOutput(DataOutput, AutoCloseable):
    """
    ObjectOutput extends the DataOutput interface to include writing of objects.
    DataOutput includes methods for output of primitive types, ObjectOutput
    extends that interface to include objects, arrays, and Strings.

    See
    - java.io.ObjectInputStream

    Since
    - 1.1
    """

    def writeObject(self, obj: "Object") -> None:
        """
        Write an object to the underlying storage or stream.  The
        class that implements this interface defines how the object is
        written.

        Arguments
        - obj: the object to be written

        Raises
        - IOException: Any of the usual Input/Output related exceptions.
        """
        ...


    def write(self, b: int) -> None:
        """
        Writes a byte. This method will block until the byte is actually
        written.

        Arguments
        - b: the byte

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def write(self, b: list[int]) -> None:
        """
        Writes an array of bytes. This method will block until the bytes
        are actually written.

        Arguments
        - b: the data to be written

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def write(self, b: list[int], off: int, len: int) -> None:
        """
        Writes a sub array of bytes.

        Arguments
        - b: the data to be written
        - off: the start offset in the data
        - len: the number of bytes that are written

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def flush(self) -> None:
        """
        Flushes the stream. This will write any buffered
        output bytes.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def close(self) -> None:
        """
        Closes the stream. This method must be called
        to release any resources associated with the
        stream.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...



"""
Python module generated from Java source file org.bukkit.util.io.Wrapper

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableMap
from java.io import Serializable
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import ConfigurationSerialization
from org.bukkit.util.io import *
from typing import Any, Callable, Iterable, Tuple


class Wrapper(Serializable):





"""
Python module generated from Java source file com.google.common.collect.AbstractMapEntry

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractMapEntry(Entry):
    """
    Implementation of the `equals`, `hashCode`, and `toString` methods of `Entry`.

    Author(s)
    - Jared Levy
    """

    def getKey(self) -> "K":
        ...


    def getValue(self) -> "V":
        ...


    def setValue(self, value: "V") -> "V":
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        """
        Returns a string representation of the form `{key`={value}}.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerPickupArrowEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import AbstractArrow
from org.bukkit.entity import Item
from org.bukkit.entity import Player
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerPickupArrowEvent(PlayerPickupItemEvent):
    """
    Thrown when a player picks up an arrow from the ground.
    """

    def __init__(self, player: "Player", item: "Item", arrow: "AbstractArrow"):
        ...


    def getArrow(self) -> "AbstractArrow":
        """
        Get the arrow being picked up by the player

        Returns
        - The arrow being picked up
        """
        ...



"""
Python module generated from Java source file org.bukkit.configuration.file.YamlRepresenter

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.configuration import ConfigurationSection
from org.bukkit.configuration.file import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import ConfigurationSerialization
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.representer import Representer
from typing import Any, Callable, Iterable, Tuple


class YamlRepresenter(Representer):

    def __init__(self):
        """
        Deprecated
        - options required
        """
        ...


    def __init__(self, options: "DumperOptions"):
        ...



"""
Python module generated from Java source file com.google.common.collect.RowSortedTable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import SortedMap
from java.util import SortedSet
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class RowSortedTable(Table):
    """
    Interface that extends `Table` and whose rows are sorted.
    
    The .rowKeySet method returns a SortedSet and the .rowMap method
    returns a SortedMap, instead of the Set and Map specified by the Table interface.

    Author(s)
    - Warren Dukes

    Since
    - 8.0
    """

    def rowKeySet(self) -> "SortedSet"["R"]:
        """
        
        
        This method returns a SortedSet, instead of the `Set` specified in the Table interface.
        """
        ...


    def rowMap(self) -> "SortedMap"["R", dict["C", "V"]]:
        """
        
        
        This method returns a SortedMap, instead of the `Map` specified in the Table interface.
        """
        ...



"""
Python module generated from Java source file java.time.Instant

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import DataInput
from java.io import DataOutput
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.time import *
from java.time.format import DateTimeFormatter
from java.time.format import DateTimeParseException
from java.time.temporal import ChronoField
from java.time.temporal import ChronoUnit
from java.time.temporal import Temporal
from java.time.temporal import TemporalAccessor
from java.time.temporal import TemporalAdjuster
from java.time.temporal import TemporalAmount
from java.time.temporal import TemporalField
from java.time.temporal import TemporalQueries
from java.time.temporal import TemporalQuery
from java.time.temporal import TemporalUnit
from java.time.temporal import UnsupportedTemporalTypeException
from java.time.temporal import ValueRange
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class Instant(Temporal, TemporalAdjuster, Comparable, Serializable):
    """
    An instantaneous point on the time-line.
    
    This class models a single instantaneous point on the time-line.
    This might be used to record event time-stamps in the application.
    
    The range of an instant requires the storage of a number larger than a `long`.
    To achieve this, the class stores a `long` representing epoch-seconds and an
    `int` representing nanosecond-of-second, which will always be between 0 and 999,999,999.
    The epoch-seconds are measured from the standard Java epoch of `1970-01-01T00:00:00Z`
    where instants after the epoch have positive values, and earlier instants have negative values.
    For both the epoch-second and nanosecond parts, a larger value is always later on the time-line
    than a smaller value.
    
    <h2>Time-scale</h2>
    
    The length of the solar day is the standard way that humans measure time.
    This has traditionally been subdivided into 24 hours of 60 minutes of 60 seconds,
    forming a 86400 second day.
    
    Modern timekeeping is based on atomic clocks which precisely define an SI second
    relative to the transitions of a Caesium atom. The length of an SI second was defined
    to be very close to the 86400th fraction of a day.
    
    Unfortunately, as the Earth rotates the length of the day varies.
    In addition, over time the average length of the day is getting longer as the Earth slows.
    As a result, the length of a solar day in 2012 is slightly longer than 86400 SI seconds.
    The actual length of any given day and the amount by which the Earth is slowing
    are not predictable and can only be determined by measurement.
    The UT1 time-scale captures the accurate length of day, but is only available some
    time after the day has completed.
    
    The UTC time-scale is a standard approach to bundle up all the additional fractions
    of a second from UT1 into whole seconds, known as *leap-seconds*.
    A leap-second may be added or removed depending on the Earth's rotational changes.
    As such, UTC permits a day to have 86399 SI seconds or 86401 SI seconds where
    necessary in order to keep the day aligned with the Sun.
    
    The modern UTC time-scale was introduced in 1972, introducing the concept of whole leap-seconds.
    Between 1958 and 1972, the definition of UTC was complex, with minor sub-second leaps and
    alterations to the length of the notional second. As of 2012, discussions are underway
    to change the definition of UTC again, with the potential to remove leap seconds or
    introduce other changes.
    
    Given the complexity of accurate timekeeping described above, this Java API defines
    its own time-scale, the *Java Time-Scale*.
    
    The Java Time-Scale divides each calendar day into exactly 86400
    subdivisions, known as seconds.  These seconds may differ from the
    SI second.  It closely matches the de facto international civil time
    scale, the definition of which changes from time to time.
    
    The Java Time-Scale has slightly different definitions for different
    segments of the time-line, each based on the consensus international
    time scale that is used as the basis for civil time. Whenever the
    internationally-agreed time scale is modified or replaced, a new
    segment of the Java Time-Scale must be defined for it.  Each segment
    must meet these requirements:
    
    - the Java Time-Scale shall closely match the underlying international
     civil time scale;
    - the Java Time-Scale shall exactly match the international civil
     time scale at noon each day;
    - the Java Time-Scale shall have a precisely-defined relationship to
     the international civil time scale.
    
    There are currently, as of 2013, two segments in the Java time-scale.
    
    For the segment from 1972-11-03 (exact boundary discussed below) until
    further notice, the consensus international time scale is UTC (with
    leap seconds).  In this segment, the Java Time-Scale is identical to
    <a href="http://www.cl.cam.ac.uk/~mgk25/time/utc-sls/">UTC-SLS</a>.
    This is identical to UTC on days that do not have a leap second.
    On days that do have a leap second, the leap second is spread equally
    over the last 1000 seconds of the day, maintaining the appearance of
    exactly 86400 seconds per day.
    
    For the segment prior to 1972-11-03, extending back arbitrarily far,
    the consensus international time scale is defined to be UT1, applied
    proleptically, which is equivalent to the (mean) solar time on the
    prime meridian (Greenwich). In this segment, the Java Time-Scale is
    identical to the consensus international time scale. The exact
    boundary between the two segments is the instant where UT1 = UTC
    between 1972-11-03T00:00 and 1972-11-04T12:00.
    
    Implementations of the Java time-scale using the JSR-310 API are not
    required to provide any clock that is sub-second accurate, or that
    progresses monotonically or smoothly. Implementations are therefore
    not required to actually perform the UTC-SLS slew or to otherwise be
    aware of leap seconds. JSR-310 does, however, require that
    implementations must document the approach they use when defining a
    clock representing the current instant.
    See Clock for details on the available clocks.
    
    The Java time-scale is used for all date-time classes.
    This includes `Instant`, `LocalDate`, `LocalTime`, `OffsetDateTime`,
    `ZonedDateTime` and `Duration`.
    
    This is a <a href="/java.base/java/lang/doc-files/ValueBased.html">value-based</a>
    class; programmers should treat instances that are
    .equals(Object) equal as interchangeable and should not
    use instances for synchronization, or unpredictable behavior may
    occur. For example, in a future release, synchronization may fail.
    The `equals` method should be used for comparisons.

    Since
    - 1.8

    Unknown Tags
    - This class is immutable and thread-safe.
    """

    EPOCH = Instant(0, 0)
    """
    Constant for the 1970-01-01T00:00:00Z epoch instant.
    """
    MIN = Instant.ofEpochSecond(MIN_SECOND, 0)
    """
    The minimum supported `Instant`, '-1000000000-01-01T00:00Z'.
    This could be used by an application as a "far past" instant.
    
    This is one year earlier than the minimum `LocalDateTime`.
    This provides sufficient values to handle the range of `ZoneOffset`
    which affect the instant in addition to the local date-time.
    The value is also chosen such that the value of the year fits in
    an `int`.
    """
    MAX = Instant.ofEpochSecond(MAX_SECOND, 999_999_999)
    """
    The maximum supported `Instant`, '1000000000-12-31T23:59:59.999999999Z'.
    This could be used by an application as a "far future" instant.
    
    This is one year later than the maximum `LocalDateTime`.
    This provides sufficient values to handle the range of `ZoneOffset`
    which affect the instant in addition to the local date-time.
    The value is also chosen such that the value of the year fits in
    an `int`.
    """


    @staticmethod
    def now() -> "Instant":
        """
        Obtains the current instant from the system clock.
        
        This will query the Clock.systemUTC() system UTC clock to
        obtain the current instant.
        
        Using this method will prevent the ability to use an alternate time-source for
        testing because the clock is effectively hard-coded.

        Returns
        - the current instant using the system clock, not null
        """
        ...


    @staticmethod
    def now(clock: "Clock") -> "Instant":
        """
        Obtains the current instant from the specified clock.
        
        This will query the specified clock to obtain the current time.
        
        Using this method allows the use of an alternate clock for testing.
        The alternate clock may be introduced using Clock dependency injection.

        Arguments
        - clock: the clock to use, not null

        Returns
        - the current instant, not null
        """
        ...


    @staticmethod
    def ofEpochSecond(epochSecond: int) -> "Instant":
        """
        Obtains an instance of `Instant` using seconds from the
        epoch of 1970-01-01T00:00:00Z.
        
        The nanosecond field is set to zero.

        Arguments
        - epochSecond: the number of seconds from 1970-01-01T00:00:00Z

        Returns
        - an instant, not null

        Raises
        - DateTimeException: if the instant exceeds the maximum or minimum instant
        """
        ...


    @staticmethod
    def ofEpochSecond(epochSecond: int, nanoAdjustment: int) -> "Instant":
        """
        Obtains an instance of `Instant` using seconds from the
        epoch of 1970-01-01T00:00:00Z and nanosecond fraction of second.
        
        This method allows an arbitrary number of nanoseconds to be passed in.
        The factory will alter the values of the second and nanosecond in order
        to ensure that the stored nanosecond is in the range 0 to 999,999,999.
        For example, the following will result in exactly the same instant:
        ```
         Instant.ofEpochSecond(3, 1);
         Instant.ofEpochSecond(4, -999_999_999);
         Instant.ofEpochSecond(2, 1000_000_001);
        ```

        Arguments
        - epochSecond: the number of seconds from 1970-01-01T00:00:00Z
        - nanoAdjustment: the nanosecond adjustment to the number of seconds, positive or negative

        Returns
        - an instant, not null

        Raises
        - DateTimeException: if the instant exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    @staticmethod
    def ofEpochMilli(epochMilli: int) -> "Instant":
        """
        Obtains an instance of `Instant` using milliseconds from the
        epoch of 1970-01-01T00:00:00Z.
        
        The seconds and nanoseconds are extracted from the specified milliseconds.

        Arguments
        - epochMilli: the number of milliseconds from 1970-01-01T00:00:00Z

        Returns
        - an instant, not null

        Raises
        - DateTimeException: if the instant exceeds the maximum or minimum instant
        """
        ...


    @staticmethod
    def from(temporal: "TemporalAccessor") -> "Instant":
        """
        Obtains an instance of `Instant` from a temporal object.
        
        This obtains an instant based on the specified temporal.
        A `TemporalAccessor` represents an arbitrary set of date and time information,
        which this factory converts to an instance of `Instant`.
        
        The conversion extracts the ChronoField.INSTANT_SECONDS INSTANT_SECONDS
        and ChronoField.NANO_OF_SECOND NANO_OF_SECOND fields.
        
        This method matches the signature of the functional interface TemporalQuery
        allowing it to be used as a query via method reference, `Instant::from`.

        Arguments
        - temporal: the temporal object to convert, not null

        Returns
        - the instant, not null

        Raises
        - DateTimeException: if unable to convert to an `Instant`
        """
        ...


    @staticmethod
    def parse(text: "CharSequence") -> "Instant":
        """
        Obtains an instance of `Instant` from a text string such as
        `2007-12-03T10:15:30.00Z`.
        
        The string must represent a valid instant in UTC and is parsed using
        DateTimeFormatter.ISO_INSTANT.

        Arguments
        - text: the text to parse, not null

        Returns
        - the parsed instant, not null

        Raises
        - DateTimeParseException: if the text cannot be parsed
        """
        ...


    def isSupported(self, field: "TemporalField") -> bool:
        """
        Checks if the specified field is supported.
        
        This checks if this instant can be queried for the specified field.
        If False, then calling the .range(TemporalField) range,
        .get(TemporalField) get and .with(TemporalField, long)
        methods will throw an exception.
        
        If the field is a ChronoField then the query is implemented here.
        The supported fields are:
        
        - `NANO_OF_SECOND`
        - `MICRO_OF_SECOND`
        - `MILLI_OF_SECOND`
        - `INSTANT_SECONDS`
        
        All other `ChronoField` instances will return False.
        
        If the field is not a `ChronoField`, then the result of this method
        is obtained by invoking `TemporalField.isSupportedBy(TemporalAccessor)`
        passing `this` as the argument.
        Whether the field is supported is determined by the field.

        Arguments
        - field: the field to check, null returns False

        Returns
        - True if the field is supported on this instant, False if not
        """
        ...


    def isSupported(self, unit: "TemporalUnit") -> bool:
        """
        Checks if the specified unit is supported.
        
        This checks if the specified unit can be added to, or subtracted from, this date-time.
        If False, then calling the .plus(long, TemporalUnit) and
        .minus(long, TemporalUnit) minus methods will throw an exception.
        
        If the unit is a ChronoUnit then the query is implemented here.
        The supported units are:
        
        - `NANOS`
        - `MICROS`
        - `MILLIS`
        - `SECONDS`
        - `MINUTES`
        - `HOURS`
        - `HALF_DAYS`
        - `DAYS`
        
        All other `ChronoUnit` instances will return False.
        
        If the unit is not a `ChronoUnit`, then the result of this method
        is obtained by invoking `TemporalUnit.isSupportedBy(Temporal)`
        passing `this` as the argument.
        Whether the unit is supported is determined by the unit.

        Arguments
        - unit: the unit to check, null returns False

        Returns
        - True if the unit can be added/subtracted, False if not
        """
        ...


    def range(self, field: "TemporalField") -> "ValueRange":
        """
        Gets the range of valid values for the specified field.
        
        The range object expresses the minimum and maximum valid values for a field.
        This instant is used to enhance the accuracy of the returned range.
        If it is not possible to return the range, because the field is not supported
        or for some other reason, an exception is thrown.
        
        If the field is a ChronoField then the query is implemented here.
        The .isSupported(TemporalField) supported fields will return
        appropriate range instances.
        All other `ChronoField` instances will throw an `UnsupportedTemporalTypeException`.
        
        If the field is not a `ChronoField`, then the result of this method
        is obtained by invoking `TemporalField.rangeRefinedBy(TemporalAccessor)`
        passing `this` as the argument.
        Whether the range can be obtained is determined by the field.

        Arguments
        - field: the field to query the range for, not null

        Returns
        - the range of valid values for the field, not null

        Raises
        - DateTimeException: if the range for the field cannot be obtained
        - UnsupportedTemporalTypeException: if the field is not supported
        """
        ...


    def get(self, field: "TemporalField") -> int:
        """
        Gets the value of the specified field from this instant as an `int`.
        
        This queries this instant for the value of the specified field.
        The returned value will always be within the valid range of values for the field.
        If it is not possible to return the value, because the field is not supported
        or for some other reason, an exception is thrown.
        
        If the field is a ChronoField then the query is implemented here.
        The .isSupported(TemporalField) supported fields will return valid
        values based on this date-time, except `INSTANT_SECONDS` which is too
        large to fit in an `int` and throws a `DateTimeException`.
        All other `ChronoField` instances will throw an `UnsupportedTemporalTypeException`.
        
        If the field is not a `ChronoField`, then the result of this method
        is obtained by invoking `TemporalField.getFrom(TemporalAccessor)`
        passing `this` as the argument. Whether the value can be obtained,
        and what the value represents, is determined by the field.

        Arguments
        - field: the field to get, not null

        Returns
        - the value for the field

        Raises
        - DateTimeException: if a value for the field cannot be obtained or
                the value is outside the range of valid values for the field
        - UnsupportedTemporalTypeException: if the field is not supported or
                the range of values exceeds an `int`
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def getLong(self, field: "TemporalField") -> int:
        """
        Gets the value of the specified field from this instant as a `long`.
        
        This queries this instant for the value of the specified field.
        If it is not possible to return the value, because the field is not supported
        or for some other reason, an exception is thrown.
        
        If the field is a ChronoField then the query is implemented here.
        The .isSupported(TemporalField) supported fields will return valid
        values based on this date-time.
        All other `ChronoField` instances will throw an `UnsupportedTemporalTypeException`.
        
        If the field is not a `ChronoField`, then the result of this method
        is obtained by invoking `TemporalField.getFrom(TemporalAccessor)`
        passing `this` as the argument. Whether the value can be obtained,
        and what the value represents, is determined by the field.

        Arguments
        - field: the field to get, not null

        Returns
        - the value for the field

        Raises
        - DateTimeException: if a value for the field cannot be obtained
        - UnsupportedTemporalTypeException: if the field is not supported
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def getEpochSecond(self) -> int:
        """
        Gets the number of seconds from the Java epoch of 1970-01-01T00:00:00Z.
        
        The epoch second count is a simple incrementing count of seconds where
        second 0 is 1970-01-01T00:00:00Z.
        The nanosecond part is returned by .getNano.

        Returns
        - the seconds from the epoch of 1970-01-01T00:00:00Z
        """
        ...


    def getNano(self) -> int:
        """
        Gets the number of nanoseconds, later along the time-line, from the start
        of the second.
        
        The nanosecond-of-second value measures the total number of nanoseconds from
        the second returned by .getEpochSecond.

        Returns
        - the nanoseconds within the second, always positive, never exceeds 999,999,999
        """
        ...


    def with(self, adjuster: "TemporalAdjuster") -> "Instant":
        """
        Returns an adjusted copy of this instant.
        
        This returns an `Instant`, based on this one, with the instant adjusted.
        The adjustment takes place using the specified adjuster strategy object.
        Read the documentation of the adjuster to understand what adjustment will be made.
        
        The result of this method is obtained by invoking the
        TemporalAdjuster.adjustInto(Temporal) method on the
        specified adjuster passing `this` as the argument.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - adjuster: the adjuster to use, not null

        Returns
        - an `Instant` based on `this` with the adjustment made, not null

        Raises
        - DateTimeException: if the adjustment cannot be made
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def with(self, field: "TemporalField", newValue: int) -> "Instant":
        """
        Returns a copy of this instant with the specified field set to a new value.
        
        This returns an `Instant`, based on this one, with the value
        for the specified field changed.
        If it is not possible to set the value, because the field is not supported or for
        some other reason, an exception is thrown.
        
        If the field is a ChronoField then the adjustment is implemented here.
        The supported fields behave as follows:
        
        - `NANO_OF_SECOND` -
         Returns an `Instant` with the specified nano-of-second.
         The epoch-second will be unchanged.
        - `MICRO_OF_SECOND` -
         Returns an `Instant` with the nano-of-second replaced by the specified
         micro-of-second multiplied by 1,000. The epoch-second will be unchanged.
        - `MILLI_OF_SECOND` -
         Returns an `Instant` with the nano-of-second replaced by the specified
         milli-of-second multiplied by 1,000,000. The epoch-second will be unchanged.
        - `INSTANT_SECONDS` -
         Returns an `Instant` with the specified epoch-second.
         The nano-of-second will be unchanged.
        
        
        In all cases, if the new value is outside the valid range of values for the field
        then a `DateTimeException` will be thrown.
        
        All other `ChronoField` instances will throw an `UnsupportedTemporalTypeException`.
        
        If the field is not a `ChronoField`, then the result of this method
        is obtained by invoking `TemporalField.adjustInto(Temporal, long)`
        passing `this` as the argument. In this case, the field determines
        whether and how to adjust the instant.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - field: the field to set in the result, not null
        - newValue: the new value of the field in the result

        Returns
        - an `Instant` based on `this` with the specified field set, not null

        Raises
        - DateTimeException: if the field cannot be set
        - UnsupportedTemporalTypeException: if the field is not supported
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def truncatedTo(self, unit: "TemporalUnit") -> "Instant":
        """
        Returns a copy of this `Instant` truncated to the specified unit.
        
        Truncating the instant returns a copy of the original with fields
        smaller than the specified unit set to zero.
        The fields are calculated on the basis of using a UTC offset as seen
        in `toString`.
        For example, truncating with the ChronoUnit.MINUTES MINUTES unit will
        round down to the nearest minute, setting the seconds and nanoseconds to zero.
        
        The unit must have a TemporalUnit.getDuration() duration
        that divides into the length of a standard day without remainder.
        This includes all supplied time units on ChronoUnit and
        ChronoUnit.DAYS DAYS. Other units throw an exception.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - unit: the unit to truncate to, not null

        Returns
        - an `Instant` based on this instant with the time truncated, not null

        Raises
        - DateTimeException: if the unit is invalid for truncation
        - UnsupportedTemporalTypeException: if the unit is not supported
        """
        ...


    def plus(self, amountToAdd: "TemporalAmount") -> "Instant":
        """
        Returns a copy of this instant with the specified amount added.
        
        This returns an `Instant`, based on this one, with the specified amount added.
        The amount is typically Duration but may be any other type implementing
        the TemporalAmount interface.
        
        The calculation is delegated to the amount object by calling
        TemporalAmount.addTo(Temporal). The amount implementation is free
        to implement the addition in any way it wishes, however it typically
        calls back to .plus(long, TemporalUnit). Consult the documentation
        of the amount implementation to determine if it can be successfully added.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - amountToAdd: the amount to add, not null

        Returns
        - an `Instant` based on this instant with the addition made, not null

        Raises
        - DateTimeException: if the addition cannot be made
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def plus(self, amountToAdd: int, unit: "TemporalUnit") -> "Instant":
        """
        Returns a copy of this instant with the specified amount added.
        
        This returns an `Instant`, based on this one, with the amount
        in terms of the unit added. If it is not possible to add the amount, because the
        unit is not supported or for some other reason, an exception is thrown.
        
        If the field is a ChronoUnit then the addition is implemented here.
        The supported fields behave as follows:
        
        - `NANOS` -
         Returns an `Instant` with the specified number of nanoseconds added.
         This is equivalent to .plusNanos(long).
        - `MICROS` -
         Returns an `Instant` with the specified number of microseconds added.
         This is equivalent to .plusNanos(long) with the amount
         multiplied by 1,000.
        - `MILLIS` -
         Returns an `Instant` with the specified number of milliseconds added.
         This is equivalent to .plusNanos(long) with the amount
         multiplied by 1,000,000.
        - `SECONDS` -
         Returns an `Instant` with the specified number of seconds added.
         This is equivalent to .plusSeconds(long).
        - `MINUTES` -
         Returns an `Instant` with the specified number of minutes added.
         This is equivalent to .plusSeconds(long) with the amount
         multiplied by 60.
        - `HOURS` -
         Returns an `Instant` with the specified number of hours added.
         This is equivalent to .plusSeconds(long) with the amount
         multiplied by 3,600.
        - `HALF_DAYS` -
         Returns an `Instant` with the specified number of half-days added.
         This is equivalent to .plusSeconds(long) with the amount
         multiplied by 43,200 (12 hours).
        - `DAYS` -
         Returns an `Instant` with the specified number of days added.
         This is equivalent to .plusSeconds(long) with the amount
         multiplied by 86,400 (24 hours).
        
        
        All other `ChronoUnit` instances will throw an `UnsupportedTemporalTypeException`.
        
        If the field is not a `ChronoUnit`, then the result of this method
        is obtained by invoking `TemporalUnit.addTo(Temporal, long)`
        passing `this` as the argument. In this case, the unit determines
        whether and how to perform the addition.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - amountToAdd: the amount of the unit to add to the result, may be negative
        - unit: the unit of the amount to add, not null

        Returns
        - an `Instant` based on this instant with the specified amount added, not null

        Raises
        - DateTimeException: if the addition cannot be made
        - UnsupportedTemporalTypeException: if the unit is not supported
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def plusSeconds(self, secondsToAdd: int) -> "Instant":
        """
        Returns a copy of this instant with the specified duration in seconds added.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - secondsToAdd: the seconds to add, positive or negative

        Returns
        - an `Instant` based on this instant with the specified seconds added, not null

        Raises
        - DateTimeException: if the result exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def plusMillis(self, millisToAdd: int) -> "Instant":
        """
        Returns a copy of this instant with the specified duration in milliseconds added.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - millisToAdd: the milliseconds to add, positive or negative

        Returns
        - an `Instant` based on this instant with the specified milliseconds added, not null

        Raises
        - DateTimeException: if the result exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def plusNanos(self, nanosToAdd: int) -> "Instant":
        """
        Returns a copy of this instant with the specified duration in nanoseconds added.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - nanosToAdd: the nanoseconds to add, positive or negative

        Returns
        - an `Instant` based on this instant with the specified nanoseconds added, not null

        Raises
        - DateTimeException: if the result exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def minus(self, amountToSubtract: "TemporalAmount") -> "Instant":
        """
        Returns a copy of this instant with the specified amount subtracted.
        
        This returns an `Instant`, based on this one, with the specified amount subtracted.
        The amount is typically Duration but may be any other type implementing
        the TemporalAmount interface.
        
        The calculation is delegated to the amount object by calling
        TemporalAmount.subtractFrom(Temporal). The amount implementation is free
        to implement the subtraction in any way it wishes, however it typically
        calls back to .minus(long, TemporalUnit). Consult the documentation
        of the amount implementation to determine if it can be successfully subtracted.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - amountToSubtract: the amount to subtract, not null

        Returns
        - an `Instant` based on this instant with the subtraction made, not null

        Raises
        - DateTimeException: if the subtraction cannot be made
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def minus(self, amountToSubtract: int, unit: "TemporalUnit") -> "Instant":
        """
        Returns a copy of this instant with the specified amount subtracted.
        
        This returns an `Instant`, based on this one, with the amount
        in terms of the unit subtracted. If it is not possible to subtract the amount,
        because the unit is not supported or for some other reason, an exception is thrown.
        
        This method is equivalent to .plus(long, TemporalUnit) with the amount negated.
        See that method for a full description of how addition, and thus subtraction, works.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - amountToSubtract: the amount of the unit to subtract from the result, may be negative
        - unit: the unit of the amount to subtract, not null

        Returns
        - an `Instant` based on this instant with the specified amount subtracted, not null

        Raises
        - DateTimeException: if the subtraction cannot be made
        - UnsupportedTemporalTypeException: if the unit is not supported
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def minusSeconds(self, secondsToSubtract: int) -> "Instant":
        """
        Returns a copy of this instant with the specified duration in seconds subtracted.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - secondsToSubtract: the seconds to subtract, positive or negative

        Returns
        - an `Instant` based on this instant with the specified seconds subtracted, not null

        Raises
        - DateTimeException: if the result exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def minusMillis(self, millisToSubtract: int) -> "Instant":
        """
        Returns a copy of this instant with the specified duration in milliseconds subtracted.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - millisToSubtract: the milliseconds to subtract, positive or negative

        Returns
        - an `Instant` based on this instant with the specified milliseconds subtracted, not null

        Raises
        - DateTimeException: if the result exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def minusNanos(self, nanosToSubtract: int) -> "Instant":
        """
        Returns a copy of this instant with the specified duration in nanoseconds subtracted.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - nanosToSubtract: the nanoseconds to subtract, positive or negative

        Returns
        - an `Instant` based on this instant with the specified nanoseconds subtracted, not null

        Raises
        - DateTimeException: if the result exceeds the maximum or minimum instant
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def query(self, query: "TemporalQuery"["R"]) -> "R":
        """
        Queries this instant using the specified query.
        
        This queries this instant using the specified query strategy object.
        The `TemporalQuery` object defines the logic to be used to
        obtain the result. Read the documentation of the query to understand
        what the result of this method will be.
        
        The result of this method is obtained by invoking the
        TemporalQuery.queryFrom(TemporalAccessor) method on the
        specified query passing `this` as the argument.
        
        Type `<R>`: the type of the result

        Arguments
        - query: the query to invoke, not null

        Returns
        - the query result, null may be returned (defined by the query)

        Raises
        - DateTimeException: if unable to query (defined by the query)
        - ArithmeticException: if numeric overflow occurs (defined by the query)
        """
        ...


    def adjustInto(self, temporal: "Temporal") -> "Temporal":
        """
        Adjusts the specified temporal object to have this instant.
        
        This returns a temporal object of the same observable type as the input
        with the instant changed to be the same as this.
        
        The adjustment is equivalent to using Temporal.with(TemporalField, long)
        twice, passing ChronoField.INSTANT_SECONDS and
        ChronoField.NANO_OF_SECOND as the fields.
        
        In most cases, it is clearer to reverse the calling pattern by using
        Temporal.with(TemporalAdjuster):
        ```
          // these two lines are equivalent, but the second approach is recommended
          temporal = thisInstant.adjustInto(temporal);
          temporal = temporal.with(thisInstant);
        ```
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - temporal: the target object to be adjusted, not null

        Returns
        - the adjusted object, not null

        Raises
        - DateTimeException: if unable to make the adjustment
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def until(self, endExclusive: "Temporal", unit: "TemporalUnit") -> int:
        """
        Calculates the amount of time until another instant in terms of the specified unit.
        
        This calculates the amount of time between two `Instant`
        objects in terms of a single `TemporalUnit`.
        The start and end points are `this` and the specified instant.
        The result will be negative if the end is before the start.
        The calculation returns a whole number, representing the number of
        complete units between the two instants.
        The `Temporal` passed to this method is converted to a
        `Instant` using .from(TemporalAccessor).
        For example, the amount in seconds between two dates can be calculated
        using `startInstant.until(endInstant, SECONDS)`.
        
        There are two equivalent ways of using this method.
        The first is to invoke this method.
        The second is to use TemporalUnit.between(Temporal, Temporal):
        ```
          // these two lines are equivalent
          amount = start.until(end, SECONDS);
          amount = SECONDS.between(start, end);
        ```
        The choice should be made based on which makes the code more readable.
        
        The calculation is implemented in this method for ChronoUnit.
        The units `NANOS`, `MICROS`, `MILLIS`, `SECONDS`,
        `MINUTES`, `HOURS`, `HALF_DAYS` and `DAYS`
        are supported. Other `ChronoUnit` values will throw an exception.
        
        If the unit is not a `ChronoUnit`, then the result of this method
        is obtained by invoking `TemporalUnit.between(Temporal, Temporal)`
        passing `this` as the first argument and the converted input temporal
        as the second argument.
        
        This instance is immutable and unaffected by this method call.

        Arguments
        - endExclusive: the end date, exclusive, which is converted to an `Instant`, not null
        - unit: the unit to measure the amount in, not null

        Returns
        - the amount of time between this instant and the end instant

        Raises
        - DateTimeException: if the amount cannot be calculated, or the end
         temporal cannot be converted to an `Instant`
        - UnsupportedTemporalTypeException: if the unit is not supported
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def atOffset(self, offset: "ZoneOffset") -> "OffsetDateTime":
        """
        Combines this instant with an offset to create an `OffsetDateTime`.
        
        This returns an `OffsetDateTime` formed from this instant at the
        specified offset from UTC/Greenwich. An exception will be thrown if the
        instant is too large to fit into an offset date-time.
        
        This method is equivalent to
        OffsetDateTime.ofInstant(Instant, ZoneId) OffsetDateTime.ofInstant(this, offset).

        Arguments
        - offset: the offset to combine with, not null

        Returns
        - the offset date-time formed from this instant and the specified offset, not null

        Raises
        - DateTimeException: if the result exceeds the supported range
        """
        ...


    def atZone(self, zone: "ZoneId") -> "ZonedDateTime":
        """
        Combines this instant with a time-zone to create a `ZonedDateTime`.
        
        This returns an `ZonedDateTime` formed from this instant at the
        specified time-zone. An exception will be thrown if the instant is too
        large to fit into a zoned date-time.
        
        This method is equivalent to
        ZonedDateTime.ofInstant(Instant, ZoneId) ZonedDateTime.ofInstant(this, zone).

        Arguments
        - zone: the zone to combine with, not null

        Returns
        - the zoned date-time formed from this instant and the specified zone, not null

        Raises
        - DateTimeException: if the result exceeds the supported range
        """
        ...


    def toEpochMilli(self) -> int:
        """
        Converts this instant to the number of milliseconds from the epoch
        of 1970-01-01T00:00:00Z.
        
        If this instant represents a point on the time-line too far in the future
        or past to fit in a `long` milliseconds, then an exception is thrown.
        
        If this instant has greater than millisecond precision, then the conversion
        will drop any excess precision information as though the amount in nanoseconds
        was subject to integer division by one million.

        Returns
        - the number of milliseconds since the epoch of 1970-01-01T00:00:00Z

        Raises
        - ArithmeticException: if numeric overflow occurs
        """
        ...


    def compareTo(self, otherInstant: "Instant") -> int:
        """
        Compares this instant to the specified instant.
        
        The comparison is based on the time-line position of the instants.
        It is "consistent with equals", as defined by Comparable.

        Arguments
        - otherInstant: the other instant to compare to, not null

        Returns
        - the comparator value, negative if less, positive if greater

        Raises
        - NullPointerException: if otherInstant is null
        """
        ...


    def isAfter(self, otherInstant: "Instant") -> bool:
        """
        Checks if this instant is after the specified instant.
        
        The comparison is based on the time-line position of the instants.

        Arguments
        - otherInstant: the other instant to compare to, not null

        Returns
        - True if this instant is after the specified instant

        Raises
        - NullPointerException: if otherInstant is null
        """
        ...


    def isBefore(self, otherInstant: "Instant") -> bool:
        """
        Checks if this instant is before the specified instant.
        
        The comparison is based on the time-line position of the instants.

        Arguments
        - otherInstant: the other instant to compare to, not null

        Returns
        - True if this instant is before the specified instant

        Raises
        - NullPointerException: if otherInstant is null
        """
        ...


    def equals(self, other: "Object") -> bool:
        """
        Checks if this instant is equal to the specified instant.
        
        The comparison is based on the time-line position of the instants.

        Arguments
        - other: the other instant, null returns False

        Returns
        - True if the other instant is equal to this one
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hash code for this instant.

        Returns
        - a suitable hash code
        """
        ...


    def toString(self) -> str:
        """
        A string representation of this instant using ISO-8601 representation.
        
        The format used is the same as DateTimeFormatter.ISO_INSTANT.

        Returns
        - an ISO-8601 representation of this instant, not null
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingSortedMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import Comparator
from java.util import Iterator
from java.util import NavigableSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingSortedMultiset(ForwardingMultiset, SortedMultiset):
    """
    A sorted multiset which forwards all its method calls to another sorted multiset. Subclasses
    should override one or more methods to modify the behavior of the backing multiset as desired per
    the <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingSortedMultiset` forward
    **indiscriminately** to the methods of the delegate. For example, overriding .add(Object, int) alone **will not** change the behavior of .add(Object), which can
    lead to unexpected behavior. In this case, you should override `add(Object)` as well,
    either providing your own implementation, or delegating to the provided `standardAdd`
    method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingSortedMultiset`.
    
    The `standard` methods and any collection views they return are not guaranteed to be
    thread-safe, even when all of the methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 15.0
    """

    def elementSet(self) -> "NavigableSet"["E"]:
        ...


    def comparator(self) -> "Comparator"["E"]:
        ...


    def descendingMultiset(self) -> "SortedMultiset"["E"]:
        ...


    def firstEntry(self) -> "Entry"["E"]:
        ...


    def lastEntry(self) -> "Entry"["E"]:
        ...


    def pollFirstEntry(self) -> "Entry"["E"]:
        ...


    def pollLastEntry(self) -> "Entry"["E"]:
        ...


    def headMultiset(self, upperBound: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def subMultiset(self, lowerBound: "E", lowerBoundType: "BoundType", upperBound: "E", upperBoundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def tailMultiset(self, lowerBound: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...



"""
Python module generated from Java source file org.bukkit.ServerTickManager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from org.bukkit.entity import Entity
from typing import Any, Callable, Iterable, Tuple


class ServerTickManager:
    """
    Manages ticking within a server.
    
    To learn more about the features surrounding this interface.

    See
    - <a href="https://minecraft.wiki/w/Commands/tick">Tick Command</a>
    """

    def isRunningNormally(self) -> bool:
        """
        Checks if the server is running normally.
        
        When the server is running normally it indicates that the server is not
        currently frozen.

        Returns
        - True if the server is running normally, otherwise False
        """
        ...


    def isStepping(self) -> bool:
        """
        Checks if the server is currently stepping.

        Returns
        - True if stepping, otherwise False
        """
        ...


    def isSprinting(self) -> bool:
        """
        Checks if the server is currently sprinting.

        Returns
        - True if sprinting, otherwise False
        """
        ...


    def isFrozen(self) -> bool:
        """
        Checks if the server is currently frozen.

        Returns
        - True if the server is frozen, otherwise False
        """
        ...


    def getTickRate(self) -> float:
        """
        Gets the current tick rate of the server.

        Returns
        - the current tick rate of the server
        """
        ...


    def setTickRate(self, tick: float) -> None:
        """
        Sets the tick rate of the server.
        
        The normal tick rate of the server is 20. No tick rate below 1.0F or
        above 10,000 can be applied to the server.

        Arguments
        - tick: the tick rate to set the server to

        Raises
        - IllegalArgumentException: if tick rate is too low or too high for
        the server to handle
        """
        ...


    def setFrozen(self, frozen: bool) -> None:
        """
        Sets the server to a frozen state that does not tick most things.

        Arguments
        - frozen: True to freeze the server, otherwise False
        """
        ...


    def stepGameIfFrozen(self, ticks: int) -> bool:
        """
        Steps the game a certain amount of ticks if the server is currently
        frozen.
        
        Steps occur when the server is in a frozen state which can be started by
        either using the in game /tick freeze command or the
        .setFrozen(boolean) method.

        Arguments
        - ticks: the amount of ticks to step the game for

        Returns
        - True if the game is now stepping. False if the game is not frozen
        so the request could not be fulfilled.
        """
        ...


    def stopStepping(self) -> bool:
        """
        Stops the current stepping if stepping is occurring.

        Returns
        - True if the game is no-longer stepping. False if the server was
        not stepping or was already done stepping.
        """
        ...


    def requestGameToSprint(self, ticks: int) -> bool:
        """
        Attempts to initiate a sprint, which executes all server ticks at a
        faster rate then normal.

        Arguments
        - ticks: the amount of ticks to sprint for

        Returns
        - True if a sprint was already initiated and was stopped, otherwise
        False
        """
        ...


    def stopSprinting(self) -> bool:
        """
        Stops the current sprint if one is currently happening.

        Returns
        - True if the game is no-longer sprinting, False if the server was
        not sprinting or was already done sprinting
        """
        ...


    def isFrozen(self, entity: "Entity") -> bool:
        """
        Checks if a given entity is frozen.

        Arguments
        - entity: the entity to check if frozen.

        Returns
        - True if the entity is currently frozen otherwise False.
        """
        ...


    def getFrozenTicksToRun(self) -> int:
        """
        Gets the amount of frozen ticks left to run.

        Returns
        - the amount of frozen ticks left to run
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.EntityFactory

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityFactory:

    def createEntitySnapshot(self, input: str) -> "EntitySnapshot":
        """
        Create a new EntitySnapshot with the supplied input.
        Accepts strings in the format output by EntitySnapshot.getAsString().

        Arguments
        - input: the input string

        Returns
        - the created EntitySnapshot

        Raises
        - IllegalArgumentException: if the input string was provided in an invalid or unsupported format
        """
        ...
